@@ -33,10 +33,24 @@
 #include <QtWidgets>
 #include <mpv/render.h>
 #include <mpv/render_gl.h>
+#include <mpv_proxy.h>
 #undef Bool
-#include <mpv/qthelper.hpp>
+#include "../../vendor/qthelper.hpp"
 #include <DGuiApplicationHelper>
 //DWIDGET_USE_NAMESPACE
+
+//add by heyi
+typedef void (*mpv_render_contextSet_update_callback)(mpv_render_context *ctx,
+                                                      mpv_render_update_fn callback,
+                                                      void *callback_ctx);
+typedef void (*mpv_render_contextReport_swap)(mpv_render_context *ctx);
+typedef void (*mpv_renderContext_free)(mpv_render_context *ctx);
+typedef int (*mpv_renderContext_create)(mpv_render_context **res, mpv_handle *mpv,
+                                        mpv_render_param *params);
+typedef int (*mpv_renderContext_render)(mpv_render_context *ctx, mpv_render_param *params);
+typedef uint64_t (*mpv_renderContext_update)(mpv_render_context *ctx);
+
+
 namespace dmr {
 class MpvGLWidget : public QOpenGLWidget
 {
@@ -44,57 +58,42 @@ class MpvGLWidget : public QOpenGLWidget
 public:
     friend class MpvProxy;
 
-    MpvGLWidget(QWidget *parent, mpv::qt::Handle h);
+    MpvGLWidget(QWidget *parent, MpvHandle h);
     virtual ~MpvGLWidget();
 
-    /*
+    /**
      * rounded clipping consumes a lot of resources, and performs bad on 4K video
      */
-    void toggleRoundedClip(bool val);
+    void toggleRoundedClip(bool bFalse);
+    //add by heyi
+    /**
+     * @brief setHandle 设置句柄
+     * @param h 传入的句柄
+     */
+    void setHandle(MpvHandle h);
 
 protected:
+    /**
+     * @brief opengl初始化 cppcheck误报
+     */
     void initializeGL() override;
-    void resizeGL(int w, int h) override;
+    void resizeGL(int nWidth, int nHeight) override;
     void paintGL() override;
 
     void setPlaying(bool);
     void setMiniMode(bool);
+    //add by heyi
+    /**
+     * @brief initMpvFuns 第一次播放需要初库始化函数指针
+     */
+    void initMpvFuns();
 
 protected slots:
     void onNewFrame();
     void onFrameSwapped();
 
 private:
-    mpv::qt::Handle _handle;
-    mpv_render_context *_render_ctx {nullptr};
-
-    bool _playing {false};
-    bool _inMiniMode {false};
-    bool _doRoundedClipping {true};
-
-    QOpenGLVertexArrayObject _vao;
-    QOpenGLBuffer _vbo;
-    QOpenGLTexture *_darkTex {nullptr};
-//    QOpenGLTexture *_darkTexbac {nullptr};
-    QOpenGLTexture *_lightTex {nullptr};
-    QOpenGLShaderProgram *_glProg {nullptr};
-
-    QOpenGLVertexArrayObject _vaoBlend;
-    QOpenGLBuffer _vboBlend;
-    QOpenGLShaderProgram *_glProgBlend {nullptr};
-    QOpenGLFramebufferObject *_fbo {nullptr};
-    QOpenGLShaderProgram *_glProgBlendCorners {nullptr};
-
-    //textures for corner
-    QOpenGLVertexArrayObject _vaoCorner;
-    QOpenGLTexture *_cornerMasks[4] {nullptr,};
-    QOpenGLBuffer _vboCorners[4];
-    QOpenGLShaderProgram *_glProgCorner {nullptr};
-
-    QImage bg_dark;
-//    QImage bg_dark_bac;
-    QImage bg_light;
-
+    void initMember();
     void updateVbo();
     void updateVboCorners();
     void updateVboBlend();
@@ -107,6 +106,42 @@ private:
 
     void prepareSplashImages();
 
+private:
+    MpvHandle m_handle;                //mpv句柄
+    mpv_render_context *m_pRenderCtx;  //mpv渲染上下文
+
+    bool m_bPlaying;                   //记录播放状态
+    bool m_bInMiniMode;                //是否是最小化
+    bool m_bDoRoundedClipping;         //
+
+    QOpenGLVertexArrayObject m_vao;    //顶点数组对象
+    QOpenGLBuffer m_vbo;               //顶点缓冲对象
+    QOpenGLTexture *m_pDarkTex;        //深色主题背景纹理
+    QOpenGLTexture *m_pLightTex;       //浅色主题背景纹理
+    QOpenGLShaderProgram *m_pGlProg;
+
+    QOpenGLVertexArrayObject m_vaoBlend;
+    QOpenGLBuffer m_vboBlend;
+    QOpenGLShaderProgram *m_pGlProgBlend;
+    QOpenGLFramebufferObject *m_pFbo;
+    QOpenGLShaderProgram *m_pGlProgBlendCorners;
+
+    //textures for corner
+    QOpenGLVertexArrayObject m_vaoCorner;
+    QOpenGLTexture *m_pCornerMasks[4];
+    QOpenGLBuffer m_vboCorners[4];
+    QOpenGLShaderProgram *m_pGlProgCorner; //着色器程序
+
+    QImage m_imgBgDark;                    //深色主题背景图
+    QImage m_imgBgLight;                   //浅色主题背景图
+
+    //add by heyi
+    mpv_render_contextSet_update_callback m_callback;
+    mpv_render_contextReport_swap m_context_report;
+    mpv_renderContext_free m_renderContex;
+    mpv_renderContext_create m_renderCreat;
+    mpv_renderContext_render m_renderContexRender;
+    mpv_renderContext_update m_renderContextUpdate;
 };
 
 }
