@@ -1,5 +1,9 @@
 /*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     mouyuankai <mouyuankai@uniontech.com>
+ *
+ * Maintainer: liuzheng <liuzheng@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,8 +35,24 @@
 #include <atomic>
 #include <mutex>
 #include "player_engine.h"
+#include <QLibrary>
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <dlfcn.h>
 
 #define SIZE_THRESHOLD (10 * 1<<20)
+#ifdef __x86_64__
+const char *path = "/usr/lib/x86_64-linux-gnu/libffmpegthumbnailer.so.4";
+#elif __mips__
+const char *path = "/usr/lib/mips64el-linux-gnuabi64/libffmpegthumbnailer.so.4";
+#elif __aarch64__
+const char *path = "/usr/lib/aarch64-linux-gnu/libffmpegthumbnailer.so.4";
+#elif __sw_64__
+const char *path = "/usr/lib/sw_64-linux-gnu/libffmpegthumbnailer.so.4";
+#else
+const char *path = "/usr/lib/i386-linux-gnu/libffmpegthumbnailer.so.4";
+#endif
 
 namespace dmr {
 static std::atomic<ThumbnailWorker *> _instance { nullptr };
@@ -41,18 +61,20 @@ static QMutex _instLock;
 static QMutex _thumbLock;
 static QWaitCondition cond;
 
+ThumbnailWorker::~ThumbnailWorker()
+{
+    free(m_pCharTime);
+}
+
 ThumbnailWorker &ThumbnailWorker::get()
 {
     if (_instance == nullptr) {
         QMutexLocker lock(&_instLock);
-        if (_instance == nullptr) {
-            _instance = new ThumbnailWorker;
+        _instance = new ThumbnailWorker;
 #ifndef __mips__
-            (*_instance).start();
+        (*_instance).start();
 #endif
-        }
     }
-
     return *_instance;
 }
 
@@ -71,8 +93,6 @@ QPixmap ThumbnailWorker::getThumb(const QUrl &url, int secs)
     QPixmap pm;
 
     if (_cache.contains(url)) {
-//        auto p = _cache[url].find(secs);
-//        pm = *p;
         pm = _cache[url].value(secs);
     }
 
@@ -84,7 +104,6 @@ void ThumbnailWorker::setPlayerEngine(PlayerEngine *pPlayerEngline)
     _engine = pPlayerEngline;
 }
 
-
 void ThumbnailWorker::requestThumb(const QUrl &url, int secs)
 {
 #ifndef __mips__
@@ -100,8 +119,42 @@ void ThumbnailWorker::requestThumb(const QUrl &url, int secs)
 
 ThumbnailWorker::ThumbnailWorker()
 {
-    thumber.setThumbnailSize(thumbSize().width() * qApp->devicePixelRatio());
-    thumber.setMaintainAspectRatio(true);
+    initThumb();
+    m_video_thumbnailer->thumbnail_size = m_video_thumbnailer->thumbnail_size * qApp->devicePixelRatio();
+
+    m_pCharTime = (char *)malloc(20);
+}
+
+QString ThumbnailWorker::libPath(const QString &strlib)
+{
+    QDir  dir;
+    QString lib_path  = QLibraryInfo::location(QLibraryInfo::LibrariesPath);
+    dir.setPath(lib_path);
+    QStringList list = dir.entryList(QStringList() << (strlib + "*"), QDir::NoDotAndDotDot | QDir::Files); //filter name with strlib
+    if (list.contains(strlib)) {
+        return strlib;
+    } else {
+        list.sort();
+    }
+
+    Q_ASSERT(list.size() > 0);
+    return list.last();
+}
+
+void ThumbnailWorker::initThumb()
+{
+    QLibrary library(libPath("libffmpegthumbnailer.so"));
+    m_mvideo_thumbnailer = (mvideo_thumbnailer) library.resolve("video_thumbnailer_create");
+    m_mvideo_thumbnailer_destroy = (mvideo_thumbnailer_destroy) library.resolve("video_thumbnailer_destroy");
+    m_mvideo_thumbnailer_create_image_data = (mvideo_thumbnailer_create_image_data) library.resolve("video_thumbnailer_create_image_data");
+    m_mvideo_thumbnailer_destroy_image_data = (mvideo_thumbnailer_destroy_image_data) library.resolve("video_thumbnailer_destroy_image_data");
+    m_mvideo_thumbnailer_generate_thumbnail_to_buffer = (mvideo_thumbnailer_generate_thumbnail_to_buffer) library.resolve("video_thumbnailer_generate_thumbnail_to_buffer");
+    if (m_mvideo_thumbnailer == nullptr || m_mvideo_thumbnailer_destroy == nullptr
+            || m_mvideo_thumbnailer_create_image_data == nullptr || m_mvideo_thumbnailer_destroy_image_data == nullptr
+            || m_mvideo_thumbnailer_generate_thumbnail_to_buffer == nullptr) {
+        return;
+    }
+    m_video_thumbnailer = m_mvideo_thumbnailer();
 }
 
 QPixmap ThumbnailWorker::genThumb(const QUrl &url, int secs)
@@ -110,9 +163,15 @@ QPixmap ThumbnailWorker::genThumb(const QUrl &url, int secs)
     QPixmap pm;
     pm.setDevicePixelRatio(dpr);
 
+    if (m_image_data == nullptr) {
+        m_image_data = m_mvideo_thumbnailer_create_image_data();
+    }
+
     QTime d(0, 0, 0);
     d = d.addSecs(secs);
-    thumber.setSeekTime(d.toString("hh:mm:ss").toStdString());
+    //memset(m_pChTime,0,strlen(m_pChTime));
+    strcpy(m_pCharTime, d.toString("hh:mm:ss").toLatin1().data());
+    m_video_thumbnailer->seek_time = m_pCharTime;
     auto file = QFileInfo(url.toLocalFile()).absoluteFilePath();
     try {
         auto e = QProcessEnvironment::systemEnvironment();
@@ -123,21 +182,21 @@ QPixmap ThumbnailWorker::genThumb(const QUrl &url, int secs)
                 WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) {
             return pm;
         }
-
-        std::vector<uint8_t> buf;
-        thumber.generateThumbnail(file.toUtf8().toStdString(),
-                                  ThumbnailerImageType::Png, buf);
-
-        auto img = QImage::fromData(buf.data(), buf.size(), "png");
+        m_mvideo_thumbnailer_generate_thumbnail_to_buffer(m_video_thumbnailer, file.toUtf8().data(),  m_image_data);
+        auto img = QImage::fromData(m_image_data->image_data_ptr, static_cast<int>(m_image_data->image_data_size), "png");
 
         pm = QPixmap::fromImage(img.scaled(thumbSize() * dpr, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation));
         pm.setDevicePixelRatio(dpr);
     } catch (const std::logic_error &e) {
     }
 
+    m_mvideo_thumbnailer_destroy_image_data(m_image_data);
+    m_image_data = nullptr;
+
     return pm;
 }
 
+//cppcheck 误报
 void ThumbnailWorker::run()
 {
     setPriority(QThread::IdlePriority);
@@ -162,7 +221,7 @@ void ThumbnailWorker::run()
             QMutexLocker lock(&_thumbLock);
             //TODO: optimize: need a lru map
             if (_cacheSize > SIZE_THRESHOLD) {
-                qDebug() << "thumb cache size exceeds maximum, clean up";
+                qInfo() << "thumb cache size exceeds maximum, clean up";
                 _cache.clear();
                 _cacheSize = 0;
             }
@@ -177,7 +236,7 @@ void ThumbnailWorker::run()
 
             QTime d(0, 0, 0);
             d = d.addSecs(w.second);
-            qDebug() << "thumb for " << w.first << d.toString("hh:mm:ss");
+            qInfo() << "thumb for " << w.first << d.toString("hh:mm:ss");
         }
 
         emit thumbGenerated(w.first, w.second);
@@ -186,10 +245,11 @@ void ThumbnailWorker::run()
     _wq.clear();
 }
 
+#ifdef __mips__
 void ThumbnailWorker::runSingle(QPair<QUrl, int> w)
 {
     if (_cacheSize > SIZE_THRESHOLD) {
-        qDebug() << "thumb cache size exceeds maximum, clean up";
+        qInfo() << "thumb cache size exceeds maximum, clean up";
         _cache.clear();
         _cacheSize = 0;
     }
@@ -203,11 +263,11 @@ void ThumbnailWorker::runSingle(QPair<QUrl, int> w)
 
         QTime d(0, 0, 0);
         d = d.addSecs(w.second);
-        qDebug() << "thumb for " << w.first << d.toString("hh:mm:ss");
+        qInfo() << "thumb for " << w.first << d.toString("hh:mm:ss");
     }
 
     emit thumbGenerated(w.first, w.second);
 }
-
+#endif
 }
 
