@@ -1,5 +1,9 @@
 /*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     xiepengfei <xiepengfei@uniontech.com>
+ *
+ * Maintainer: liuzheng <liuzheng@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,6 +34,7 @@
 
 #include "config.h"
 #include "compositing_manager.h"
+#include "utils.h"
 #ifndef _LIBDMR_
 #include "options.h"
 #endif
@@ -45,7 +50,7 @@
 #include <GL/glx.h>
 #include <GL/glxext.h>
 #undef Bool
-#include <mpv/qthelper.hpp>
+#include "../vendor/qthelper.hpp"
 
 typedef const char *glXGetScreenDriver_t (Display *dpy, int scrNum);
 
@@ -63,6 +68,7 @@ static CompositingManager *_compManager = nullptr;
 class PlatformChecker
 {
 public:
+    PlatformChecker() {}
     Platform check()
     {
         QProcess uname;
@@ -71,24 +77,24 @@ public:
             if (uname.waitForFinished()) {
                 auto data = uname.readAllStandardOutput();
                 string machine(data.trimmed().constData());
-                qDebug() << QString("machine: %1").arg(machine.c_str());
+                qInfo() << QString("machine: %1").arg(machine.c_str());
 
                 QRegExp re("x86.*|i?86|ia64", Qt::CaseInsensitive);
                 if (re.indexIn(C2Q(machine)) != -1) {
-                    qDebug() << "match x86";
+                    qInfo() << "match x86";
                     _pf = Platform::X86;
 
                 } else if (machine.find("alpha") != string::npos
                            || machine.find("sw_64") != string::npos) {
                     // shenwei
-                    qDebug() << "match shenwei";
+                    qInfo() << "match shenwei";
                     _pf = Platform::Alpha;
 
                 } else if (machine.find("mips") != string::npos) { // loongson
-                    qDebug() << "match loongson";
+                    qInfo() << "match loongson";
                     _pf = Platform::Alpha;
                 } else if (machine.find("aarch64") != string::npos) { // ARM64
-                    qDebug() << "match arm";
+                    qInfo() << "match arm";
                     _pf = Platform::Arm64;
                 }
             }
@@ -115,9 +121,14 @@ CompositingManager &CompositingManager::get()
 
 CompositingManager::CompositingManager()
 {
-    _hasCard = false;
-    _platform = PlatformChecker().check();
-
+    initMember();
+#ifdef __aarch64__
+    if (dmr::utils::check_wayland_env()) {
+        _composited = true;
+        qInfo() << __func__ << "Composited is " << _composited;
+        return;
+    }
+#endif
     softDecodeCheck();   //检测是否是kunpeng920（是否走软解码）
 
     _composited = false;
@@ -141,28 +152,26 @@ CompositingManager::CompositingManager()
             } else if (isDriverLoadedCorrectly() || isDirectRendered()) {
 #ifdef __aarch64__
                 _composited = false;
-                qDebug() << "__aarch64__  isDirectRendered";
+                qInfo() << "__aarch64__  isDirectRendered";
                 if (isDriverLoadedCorrectly()) {    //如果有独立显卡
                     _composited = true;
-                    qDebug() << "__aarch64__  isDriverLoadedCorrectly";
+                    qInfo() << "__aarch64__  isDriverLoadedCorrectly";
                 }
-#elif __mips__
+#elif defined (__mips__)
                 _composited = false;
-                qDebug() << "__mips__";
+                qInfo() << "__mips__";
 #else
+                vector<string> drivers = {"zx"};
+                m_setSpecialControls = m_setSpecialControls || is_card_exists(0, drivers);
                 _composited = true;
-                qDebug() << "__X86__";
+                qInfo() << "__X86__";
 #endif
             } else {
-                GetScreenDriver = (glXGetScreenDriver_t *)glXGetProcAddressARB ((const GLubyte *)"glXGetScreenDriver");
+                GetScreenDriver = reinterpret_cast<glXGetScreenDriver_t *>(glXGetProcAddressARB(reinterpret_cast<const GLubyte *>("glXGetScreenDriver")));
                 if (GetScreenDriver) {
-                    const char *name = (*GetScreenDriver) (QX11Info::display(), QX11Info::appScreen());
-                    qDebug() << "dri driver: " << name;
+                    const char *name = (*GetScreenDriver)(QX11Info::display(), QX11Info::appScreen());
+                    qInfo() << "dri driver: " << name;
                     _composited = name != nullptr;
-                    //        } else {
-                    //            if (isDriverLoadedCorrectly() && isDirectRendered()) {
-                    //                _composited = true;
-                    //            }
                 }
             }
 
@@ -175,7 +184,7 @@ CompositingManager::CompositingManager()
             }
 #endif
         }
-        qDebug() << "From gsetting, composition about opengl :" << gsettings.get("composited").toString();
+        qInfo() << "From gsetting, composition about opengl :" << gsettings.get("composited").toString();
     } else { /* if(gsettings.get("composited").toString() == "Default")*/
         if (QProcessEnvironment::systemEnvironment().value("SANDBOX") == "flatpak") {
             _composited = QFile::exists("/dev/dri/card0");
@@ -184,15 +193,11 @@ CompositingManager::CompositingManager()
         } else if (isDriverLoadedCorrectly() || isDirectRendered()) {
             _composited = true;
         } else {
-            GetScreenDriver = (glXGetScreenDriver_t *)glXGetProcAddressARB ((const GLubyte *)"glXGetScreenDriver");
+            GetScreenDriver = reinterpret_cast<glXGetScreenDriver_t *>(glXGetProcAddressARB(reinterpret_cast<const GLubyte *>("glXGetScreenDriver")));
             if (GetScreenDriver) {
-                const char *name = (*GetScreenDriver) (QX11Info::display(), QX11Info::appScreen());
-                qDebug() << "dri driver: " << name;
+                const char *name = (*GetScreenDriver)(QX11Info::display(), QX11Info::appScreen());
+                qInfo() << "dri driver: " << name;
                 _composited = name != nullptr;
-                //        } else {
-                //            if (isDriverLoadedCorrectly() && isDirectRendered()) {
-                //                _composited = true;
-                //            }
             }
         }
 
@@ -217,117 +222,93 @@ CompositingManager::CompositingManager()
         _composited = false;   //2020.3.19龙芯增加显卡需保留检测显卡方案
     }
 #endif
-    qDebug() << "composited:" << _composited;
-    auto e = QProcessEnvironment::systemEnvironment();
-    QString XDG_SESSION_TYPE = e.value(QStringLiteral("XDG_SESSION_TYPE"));
-    QString WAYLAND_DISPLAY = e.value(QStringLiteral("WAYLAND_DISPLAY"));
-
-    if (XDG_SESSION_TYPE == QLatin1String("wayland") ||
-            WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) {
-        _composited = false;
-    }
-#if defined (__mips__) || defined (__aarch64__) || defined (__sw_64__)
+    qInfo() << "composited:" << _composited;
+#if !defined (__x86_64__)
     if (_composited) {
-        _hasCard = _composited;
+        m_bHasCard = _composited;
         _composited = false;
-        qDebug() << "hasCard: " << _hasCard;
+        qInfo() << "hasCard: " << m_bHasCard;
     }
 #endif
-    qDebug() << __func__ << "Composited is " << _composited;
+    //读取配置
+    m_pMpvConfig = new QMap<QString, QString>;
+    utils::getPlayProperty("/etc/mpv/play.conf", m_pMpvConfig);
+    if (m_pMpvConfig->contains("vo")) {
+        QString value = m_pMpvConfig->find("vo").value();
+        if ("libmpv" == value) {
+            _composited = true;//libmpv只能走opengl
+        }
+    }
+    qInfo() << __func__ << "Composited is " << _composited;
 }
 
 CompositingManager::~CompositingManager()
 {
+    delete m_pMpvConfig;
+    m_pMpvConfig = nullptr;
 }
 
+#if !defined (__x86_64__)
 bool CompositingManager::hascard()
 {
-    return _hasCard;
-}
-
-void CompositingManager::softDecodeCheck()
-{
-    QProcess uname;
-    char* data = (char*)malloc(100);
-    uname.start("cat /proc/cpuinfo");
-    if (uname.waitForStarted()) {
-        if (uname.waitForFinished()) {
-            while (uname.readLine(data,99)>0) {
-                QString strData(data);
-                QStringList listPara = strData.split(":");
-
-                if(listPara.size()<2)
-                {
-                    continue;
-                }
-
-                if(listPara.at(0).contains("model name")
-                   && listPara.at(1).contains("Kunpeng 920"))
-                {
-                    m_bOnlySoftDecode = true;
-                }
-            }
-        }
-    }
-    free(data);
-    //浪潮 inspur softdecode
-    QProcess inspur;
-    inspur.start("cat /sys/class/dmi/id/board_vendor");
-    if (inspur.waitForStarted() && inspur.waitForFinished()) {
-        QString drv = QString::fromUtf8(inspur.readAllStandardOutput().trimmed().constData());
-        qDebug() << "inspur check : " << drv;
-        m_bOnlySoftDecode =  m_bOnlySoftDecode || drv.contains("Inspur");
-    }
-}
-
-bool CompositingManager::isOnlySoftDecode()
-{
-    return m_bOnlySoftDecode;
+    return m_bHasCard;
 }
+#endif
 
 // Attempt to reuse mpv's code for detecting whether we want GLX or EGL (which
 // is tricky to do because of hardware decoding concerns). This is not pretty,
 // but quite effective and without having to duplicate too much GLX/EGL code.
-static QString probeHwdecInterop()
+/*static QString probeHwdecInterop()
 {
-    auto mpv = mpv::qt::Handle::FromRawHandle(mpv_create());
-    if (!mpv)
-        return "";
-    mpv::qt::set_property(mpv, "hwdec-preload", "auto");
-    // Actually creating a window is required. There is currently no way to keep
-    // this window hidden or invisible.
-    mpv::qt::set_property(mpv, "force-window", true);
-    // As a mitigation, put the window in the top/right corner, and make it as
-    // small as possible by forcing 1x1 size and removing window borders.
-    mpv::qt::set_property(mpv, "geometry", "1x1+0+0");
-    mpv::qt::set_property(mpv, "border", false);
-    if (mpv_initialize(mpv) < 0)
-        return "";
-    // return "auto"
-    return mpv::qt::get_property(mpv, "gpu-hwdec-interop").toString();
-}
+//    auto mpv = mpv::qt::Handle::FromRawHandle(mpv_create());
+//    if (!mpv)
+//        return "";
+//    mpv::qt::set_property(mpv, "hwdec-preload", "auto");
+//    // Actually creating a window is required. There is currently no way to keep
+//    // this window hidden or invisible.
+//    mpv::qt::set_property(mpv, "force-window", true);
+//    // As a mitigation, put the window in the top/right corner, and make it as
+//    // small as possible by forcing 1x1 size and removing window borders.
+//    mpv::qt::set_property(mpv, "geometry", "1x1+0+0");
+//    mpv::qt::set_property(mpv, "border", false);
+//    if (mpv_initialize(mpv) < 0)
+//        return "";
+//    // return "auto"
+//    return mpv::qt::get_property(mpv, "gpu-hwdec-interop").toString();
+    return QString("");
+}*/
 
 static OpenGLInteropKind _interopKind = OpenGLInteropKind::INTEROP_NONE;
 
 bool CompositingManager::runningOnVmwgfx()
 {
     static bool s_runningOnVmwgfx = false;
-    static bool s_checked = false;
+//    static bool s_checked = false;
 
-    if (!s_checked) {
-        for (int id = 0; id <= 10; id++) {
-            if (!QFile::exists(QString("/sys/class/drm/card%1").arg(id))) break;
-            if (is_device_viable(id)) {
-                vector<string> drivers = {"vmwgfx"};
-                s_runningOnVmwgfx = is_card_exists(id, drivers);
-                break;
-            }
+//    if (!s_checked) {
+    for (int id = 0; id <= 10; id++) {
+        if (!QFile::exists(QString("/sys/class/drm/card%1").arg(id))) break;
+        if (is_device_viable(id)) {
+            vector<string> drivers = {"vmwgfx"};
+            s_runningOnVmwgfx = is_card_exists(id, drivers);
+            break;
         }
+//        }
     }
 
     return s_runningOnVmwgfx;
 }
 
+bool CompositingManager::isPadSystem()
+{
+    return false;
+}
+
+bool CompositingManager::isZXIntgraphics() const
+{
+    return m_bZXIntgraphics;
+}
+
 bool CompositingManager::runningOnNvidia()
 {
     static bool s_runningOnNvidia = false;
@@ -344,25 +325,70 @@ bool CompositingManager::runningOnNvidia()
     return s_runningOnNvidia;
 }
 
+void CompositingManager::softDecodeCheck()
+{
+    QProcess uname;
+    char *data = (char *)malloc(100);
+    uname.start("cat /proc/cpuinfo");
+    if (uname.waitForStarted()) {
+        if (uname.waitForFinished()) {
+            while (uname.readLine(data, 99) > 0) {
+                QString strData(data);
+                QStringList listPara = strData.split(":");
+
+                if (listPara.size() < 2) {
+                    continue;
+                }
+
+                if (listPara.at(0).contains("model name")
+                        && listPara.at(1).contains("Kunpeng 920")) {
+                    m_bOnlySoftDecode = true;
+                }
+            }
+        }
+    }
+    free(data);
+    //浪潮 inspur softdecode
+    QProcess inspur;
+    inspur.start("cat /sys/class/dmi/id/board_vendor");
+    if (inspur.waitForStarted() && inspur.waitForFinished()) {
+        QString drv = QString::fromUtf8(inspur.readAllStandardOutput().trimmed().constData());
+        qInfo() << "inspur check : " << drv;
+        m_bOnlySoftDecode =  m_bOnlySoftDecode || drv.contains("Inspur");
+        m_setSpecialControls = drv.contains("Ruijie");
+    }
+}
+
+bool CompositingManager::isOnlySoftDecode()
+{
+    return m_bOnlySoftDecode;
+}
+
+bool CompositingManager::isSpecialControls()
+{
+    return m_setSpecialControls;
+}
+
 void CompositingManager::detectOpenGLEarly()
 {
     static bool detect_run = false;
 
     if (detect_run) return;
 
-    auto probed = probeHwdecInterop();
-    qDebug() << "probeHwdecInterop" << probed
-             << qgetenv("QT_XCB_GL_INTERGRATION");
+    ///function probeHwdecInterop() always returns QString(""), this code was not used
+//    auto probed = probeHwdecInterop();
+//    qInfo() << "probeHwdecInterop" << probed
+//             << qgetenv("QT_XCB_GL_INTERGRATION");
 
-    if (probed == "auto") {
-        _interopKind = INTEROP_AUTO;
-    } else if (probed == "vaapi-egl") {
-        _interopKind = INTEROP_VAAPI_EGL;
-    } else if (probed == "vaapi-glx") {
-        _interopKind = INTEROP_VAAPI_GLX;
-    } else if (probed == "vdpau-glx") {
-        _interopKind = INTEROP_VDPAU_GLX;
-    }
+//    if (probed == "auto") {
+//        _interopKind = INTEROP_AUTO;
+//    } else if (probed == "vaapi-egl") {
+//        _interopKind = INTEROP_VAAPI_EGL;
+//    } else if (probed == "vaapi-glx") {
+//        _interopKind = INTEROP_VAAPI_GLX;
+//    } else if (probed == "vdpau-glx") {
+//        _interopKind = INTEROP_VDPAU_GLX;
+//    }
 
 #ifndef USE_DXCB
     /*
@@ -407,14 +433,14 @@ void CompositingManager::detectPciID()
         auto data = pcicheck.readAllStandardOutput();
 
         QString output(data.trimmed().constData());
-        qDebug() << "CompositingManager::detectPciID()" << output.split(QChar('\n')).count();
+        qInfo() << "CompositingManager::detectPciID()" << output.split(QChar('\n')).count();
 
         QStringList outlist = output.split(QChar('\n'));
         foreach (QString line, outlist) {
-//            qDebug()<<"CompositingManager::detectPciID():"<<line;
+//            qInfo()<<"CompositingManager::detectPciID():"<<line;
             if (line.contains(QString("00:02.0"))) {
                 if (line.contains(QString("8086")) && line.contains(QString("1912"))) {
-                    qDebug() << "CompositingManager::detectPciID():need to change to iHD";
+                    qInfo() << "CompositingManager::detectPciID():need to change to iHD";
                     qputenv("LIBVA_DRIVER_NAME", "iHD");
                     break;
                 }
@@ -423,6 +449,14 @@ void CompositingManager::detectPciID()
     }
 }
 
+void CompositingManager::getMpvConfig(QMap<QString, QString> *&aimMap)
+{
+    aimMap = nullptr;
+    if (nullptr != m_pMpvConfig) {
+        aimMap = m_pMpvConfig;
+    }
+}
+
 OpenGLInteropKind CompositingManager::interopKind()
 {
     return _interopKind;
@@ -433,9 +467,10 @@ bool CompositingManager::isDriverLoadedCorrectly()
     static QRegExp aiglx_err("\\(EE\\)\\s+AIGLX error");
     static QRegExp dri_ok("direct rendering: DRI\\d+ enabled");
     static QRegExp swrast("GLX: Initialized DRISWRAST");
+    static QRegExp regZX("loading driver: zx");
 
     QString xorglog = QString("/var/log/Xorg.%1.log").arg(QX11Info::appScreen());
-    qDebug() << "check " << xorglog;
+    qInfo() << "check " << xorglog;
     QFile f(xorglog);
     if (!f.open(QFile::ReadOnly)) {
         qWarning() << "can not open " << xorglog;
@@ -446,31 +481,36 @@ bool CompositingManager::isDriverLoadedCorrectly()
     while (!ts.atEnd()) {
         QString ln = ts.readLine();
         if (aiglx_err.indexIn(ln) != -1) {
-            qDebug() << "found aiglx error";
+            qInfo() << "found aiglx error";
             return false;
         }
 
         if (dri_ok.indexIn(ln) != -1) {
-            qDebug() << "dri enabled successfully";
+            qInfo() << "dri enabled successfully";
             return true;
         }
 
         if (swrast.indexIn(ln) != -1) {
-            qDebug() << "swrast driver used";
+            qInfo() << "swrast driver used";
             return false;
         }
-    }
 
+        if (regZX.indexIn(ln) != -1) {
+            m_bZXIntgraphics = true;
+        }
+    }
+    f.close();
     return true;
 }
 
-void CompositingManager::overrideCompositeMode(bool useCompositing)
-{
-    if (_composited != useCompositing) {
-        qInfo() << "override composited = " << useCompositing;
-        _composited = useCompositing;
-    }
-}
+//cppcheck 修改
+//void CompositingManager::overrideCompositeMode(bool useCompositing)
+//{
+//    if (_composited != useCompositing) {
+//        qInfo() << "override composited = " << useCompositing;
+//        _composited = useCompositing;
+//    }
+//}
 
 using namespace std;
 
@@ -485,10 +525,8 @@ bool CompositingManager::is_card_exists(int id, const vector<string> &drivers)
     }
 
     string driver = basename(buf2);
-    qDebug() << "drm driver " << driver.c_str();
-    if (std::any_of(drivers.cbegin(), drivers.cend(), [ = ](string s) {
-    return s == driver;
-})) {
+    qInfo() << "drm driver " << driver.c_str();
+    if (std::any_of(drivers.cbegin(), drivers.cend(), [ = ](string s) {return s == driver;})) {
         return true;
     }
 
@@ -513,7 +551,10 @@ bool CompositingManager::is_device_viable(int id)
         }
 
         int enabled = 0;
-        fscanf(fp, "%d", &enabled);
+        int error = fscanf(fp, "%d", &enabled);
+        if (error < 0) {
+            qInfo() << "someting error";
+        }
         fclose(fp);
 
         // nouveau may write 2, others 1
@@ -536,16 +577,26 @@ bool CompositingManager::isProprietaryDriver()
     return false;
 }
 
+void CompositingManager::initMember()
+{
+    m_pMpvConfig = nullptr;
+    _platform = PlatformChecker().check();
+
+    m_bZXIntgraphics = false;
+    m_bHasCard = false;
+}
+
 //this is not accurate when proprietary driver used
 bool CompositingManager::isDirectRendered()
 {
-    QProcess xdriinfo;
-    xdriinfo.start("xdriinfo driver 0");
-    if (xdriinfo.waitForStarted() && xdriinfo.waitForFinished()) {
-        QString drv = QString::fromUtf8(xdriinfo.readAllStandardOutput().trimmed().constData());
-        qDebug() << "xdriinfo: " << drv;
-        return !drv.contains("not direct rendering capable");
-    }
+//避免klu 上产生xdriinfo的coredump
+//    QProcess xdriinfo;
+//    xdriinfo.start("xdriinfo driver 0");
+//    if (xdriinfo.waitForStarted() && xdriinfo.waitForFinished()) {
+//        QString drv = QString::fromUtf8(xdriinfo.readAllStandardOutput().trimmed().constData());
+//        qInfo() << "xdriinfo: " << drv;
+//        return !drv.contains("not direct rendering capable");
+//    }
 
     return true;
 }
@@ -572,7 +623,7 @@ PlayerOptionList CompositingManager::getProfile(const QString &name)
     while (p != files.end()) {
         QFileInfo fi(*p);
         if (fi.exists()) {
-            qDebug() << "load" << fi.absoluteFilePath();
+            qInfo() << "load" << fi.absoluteFilePath();
             QFile f(fi.absoluteFilePath());
             f.open(QIODevice::ReadOnly);
             QTextStream ts(&f);
@@ -581,13 +632,14 @@ PlayerOptionList CompositingManager::getProfile(const QString &name)
                 if (l.isEmpty()) continue;
 
                 auto kv = l.split("=");
-                qDebug() << l << kv;
+                qInfo() << l << kv;
                 if (kv.size() == 1) {
                     ol.push_back(qMakePair(kv[0], QString::fromUtf8("")));
                 } else {
                     ol.push_back(qMakePair(kv[0], kv[1]));
                 }
             }
+            f.close();
 
             return ol;
         }
