@@ -75,9 +75,10 @@ public:
      */
     static OpenGLInteropKind interopKind();
     static bool runningOnVmwgfx();
+    static bool isPadSystem();   //是否是平板设备
+#if !defined (__x86_64__)
     bool hascard();
-    void softDecodeCheck();
-    bool isOnlySoftDecode();
+#endif
 
     /**
      * override auto-detected compositing state.
@@ -95,10 +96,24 @@ public:
         return _platform;
     }
 
+    bool isTestFlag() const
+    {
+        return _isCoreFlag;
+    }
+    void setTestFlag(bool flag)
+    {
+        _isCoreFlag = flag;
+    }
+    bool isZXIntgraphics() const;
+
     PlayerOptionList getProfile(const QString &name);
     PlayerOptionList getBestProfile(); // best for current platform and env
     static void detectPciID();
     static bool runningOnNvidia();
+    void softDecodeCheck();
+    bool isOnlySoftDecode();
+    bool isSpecialControls();
+    void getMpvConfig(QMap<QString, QString> *&aimMap);
 
 signals:
     void compositingChanged(bool);
@@ -108,14 +123,23 @@ private:
     bool isDriverLoadedCorrectly();
     bool isDirectRendered();
     bool isProprietaryDriver();
+    /**
+     * @brief initMember 初始化成员变量
+     */
+    void initMember();
 
     static bool is_device_viable(int id);
     static bool is_card_exists(int id, const std::vector<std::string> &drivers);
 
     bool _composited {false};
     Platform _platform {Platform::Unknown};
-    bool _hasCard;
+    bool _isCoreFlag {false};
+    bool m_bHasCard;
     bool m_bOnlySoftDecode {false};  //kunpeng920走软解码
+    bool m_setSpecialControls {false};
+    bool m_bZXIntgraphics;
+    //保存配置
+    QMap<QString, QString> *m_pMpvConfig;
 };
 }
 
