@@ -1,5 +1,9 @@
 /*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     fengli <fengli@uniontech.com>
+ *
+ * Maintainer: xiepengfei <xiepengfei@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -88,8 +92,9 @@ static QString hash_file(const QFileInfo &fi)
         mds.append(QString::fromLatin1((const char *)md5, 32));
 #endif
     });
+    f.close();
 
-    qDebug() << mds.join(";");
+    qInfo() << mds.join(";");
     //Qt seems has a bug that ; will not be encoded as %3B in url query
     return mds.join("%3B");
 }
@@ -168,17 +173,17 @@ void OnlineSubtitle::replyReceived(QNetworkReply *reply)
                 subtitlesDownloadComplete();
             }
         }
-        qDebug() << reply->errorString();
+        qInfo() << reply->errorString();
         reply->deleteLater();
         return;
     }
 
     if (reply->property("type") == "meta") {
         auto data = reply->readAll();
-        qDebug() << "data size " << data.size() << (int)data[0];
+        qInfo() << "data size " << data.size() << static_cast<int>(data[0]);
         // fix bug 24817 by ZhuYuliang
-        if ((0 == data.size()) || (data.size() == 1 && ((int)data[0] == -1) || (int)data[0] == 255)) {
-            qDebug() << "no subtitle found";
+        if ((0 == data.size()) || (((data.size() == 1) && (static_cast<int>(data[0]) == -1)) || (static_cast<int>(data[0]) == 255))) {
+            qInfo() << "no subtitle found";
             _lastReason = FailReason::NoSubFound;
             emit onlineSubtitleStateChanged(_lastReason);
             reply->deleteLater();
@@ -187,7 +192,7 @@ void OnlineSubtitle::replyReceived(QNetworkReply *reply)
 
         auto json = QJsonDocument::fromJson(data);
         if (json.isArray()) {
-            qDebug() << json;
+            qInfo() << json;
             _subs.clear();
 
             for (auto v : json.array()) {
@@ -220,7 +225,7 @@ void OnlineSubtitle::replyReceived(QNetworkReply *reply)
         auto disposition = reply->header(QNetworkRequest::ContentDispositionHeader);
         if (disposition.isValid()) {
             //set name to disposition filename
-            qDebug() << disposition;
+            qInfo() << disposition;
         } else if (reply->hasRawHeader("Content-Disposition")) {
             QByteArray name;
             auto bytes = reply->rawHeader("Content-Disposition");
@@ -260,7 +265,7 @@ void OnlineSubtitle::replyReceived(QNetworkReply *reply)
             QFile::remove(path);
         } else {
             _subs[id].local = path;
-            qDebug() << "save to " << path;
+            qInfo() << "save to " << path;
         }
 
         if (_pendingDownloads <= 0) {
@@ -285,7 +290,7 @@ bool OnlineSubtitle::hasHashConflict(const QString &path, const QString &tmpl, Q
         s = s.replace(QRegExp("\\[\\d+\\]"), "");
         if (tmpl == s) {
             auto h = utils::FullFileHash(di.fileInfo());
-            qDebug() << "found " << di.fileName() << h;
+            qInfo() << "found " << di.fileName() << h;
             if (h == md5) {
                 conflictPath = di.filePath();
                 return true;
@@ -310,7 +315,7 @@ void OnlineSubtitle::downloadSubtitles()
         req.setUrl(url);
 
         auto *reply = _nam->get(req);
-        //qDebug() << __func__ << sub.link << url;
+        //qInfo() << __func__ << sub.link << url;
         reply->setProperty("type", "sub");
         reply->setProperty("id", sub.id);
     }
@@ -341,7 +346,7 @@ void OnlineSubtitle::requestSubtitle(const QUrl &url)
     params.setQuery(q);
     auto data = params.query(QUrl::FullyEncoded).toUtf8();
 
-    //qDebug() << req_url << params.query(QUrl::FullyEncoded);
+    //qInfo() << req_url << params.query(QUrl::FullyEncoded);
 
     QNetworkRequest req;
     req.setUrl(shooter.apiurl);
