@@ -1,5 +1,9 @@
 /*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     fengli <fengli@uniontech.com>
+ *
+ * Maintainer: xiepengfei <xiepengfei@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,9 +37,11 @@
 #include "playlist_model.h"
 #include "movie_configuration.h"
 #include "online_sub.h"
-
 #include "mpv_proxy.h"
 #include "compositing_manager.h"
+#include "dguiapplicationhelper.h"
+
+#include <QPainterPath>
 
 #ifndef _LIBDMR_
 #include "dmr_settings.h"
@@ -43,9 +49,17 @@
 
 #include "drecentmanager.h"
 DCORE_USE_NAMESPACE
+DGUI_USE_NAMESPACE
 
 namespace dmr {
 
+const QStringList PlayerEngine::audio_filetypes = {"*.mp3", "*.ogg", "*.wav", "*.wma", "*.m4a", "*.aac", "*.ac3", "*.ape", "*.flac", "*.ra", "*.mka", "*.dts", "*.opus", "*.amr"};
+const QStringList PlayerEngine::video_filetypes = {
+    "*.avs2"/*支持avs2视频格式*/, "*.3g2", "*.3ga", "*.3gp", "*.3gp2", "*.3gpp", "*.amv", "*.asf", "*.asx", "*.avf", "*.avi", "*.bdm", "*.bdmv", "*.bik", "*.clpi", "*.cpi", "*.dat", "*.divx", "*.drc", "*.dv", "*.dvr-ms", "*.f4v", "*.flv", "*.gvi", "*.gxf", "*.hdmov", "*.hlv", "*.iso", "*.letv", "*.lrv", "*.m1v", "*.m2p", "*.m2t", "*.m2ts", "*.m2v", "*.m3u", "*.m3u8", "*.m4v", "*.mkv", "*.moov", "*.mov", "*.mov", "*.mp2", "*.mp2v", "*.mp4", "*.mp4v", "*.mpe", "*.mpeg", "*.mpeg1", "*.mpeg2", "*.mpeg4", "*.mpg", "*.mpl", "*.mpls", "*.mpv", "*.mpv2", "*.mqv", "*.mts", "*.mts", "*.mtv", "*.mxf", "*.mxg", "*.nsv", "*.nuv", "*.ogg", "*.ogm", "*.ogv", "*.ogx", "*.ps", "*.qt", "*.qtvr", "*.ram", "*.rec", "*.rm", "*.rm", "*.rmj", "*.rmm", "*.rms", "*.rmvb", "*.rmx", "*.rp", "*.rpl", "*.rv", "*.rvx", "*.thp", "*.tod", "*.tp", "*.trp", "*.ts", "*.tts", "*.txd", "*.vcd", "*.vdr", "*.vob", "*.vp8", "*.vro", "*.webm", "*.wm", "*.wmv", "*.wtv", "*.xesc", "*.xspf"
+};
+
+const QStringList PlayerEngine::subtitle_suffixs = {"ass", "sub", "srt", "aqt", "jss", "gsub", "ssf", "ssa", "smi", "usf", "idx"};
+
 PlayerEngine::PlayerEngine(QWidget *parent)
     : QWidget(parent)
 {
@@ -68,6 +82,8 @@ PlayerEngine::PlayerEngine(QWidget *parent)
         connect(_current, &Backend::mpvWarningLogsChanged, this, &PlayerEngine::mpvWarningLogsChanged);
         connect(_current, &Backend::urlpause, this, &PlayerEngine::urlpause);
         l->addWidget(_current);
+
+        //_current->firstInit();
     }
 
     connect(&_networkConfigMng, &QNetworkConfigurationManager::onlineStateChanged, this, &PlayerEngine::onlineStateChanged);
@@ -81,31 +97,36 @@ PlayerEngine::PlayerEngine(QWidget *parent)
 
     connect(&OnlineSubtitle::get(), &OnlineSubtitle::subtitlesDownloadedFor,
             this, &PlayerEngine::onSubtitlesDownloaded);
-    addSubSearchPath(OnlineSubtitle::get().storeLocation());
+    //heyi need
+    //addSubSearchPath(OnlineSubtitle::get().storeLocation());
 
     _playlist = new PlaylistModel(this);
     connect(_playlist, &PlaylistModel::asyncAppendFinished, this,
             &PlayerEngine::onPlaylistAsyncAppendFinished, Qt::DirectConnection);
+    connect(_playlist, &PlaylistModel::updateDuration, this, &PlayerEngine::updateDuration);
 }
 
 PlayerEngine::~PlayerEngine()
 {
-    disconnect(_playlist, 0, 0, 0);
+    disconnect(_playlist, nullptr, nullptr, nullptr);
     delete _playlist;
     _playlist = nullptr;
 
     if (_current) {
-        disconnect(_current, 0, 0, 0);
+        disconnect(_current, nullptr, nullptr, nullptr);
         delete _current;
         _current = nullptr;
     }
-    qDebug() << __func__;
+    qInfo() << __func__;
 }
 
 bool PlayerEngine::isPlayableFile(const QUrl &url)
 {
+    // 根据后缀不能准确判断一个文件是否能播放
+    // 用是否包含音视频流判断更为准确
     if (url.isLocalFile()) {
-        return (isPlayableFile(url.path()) || isAudioFile(url.path()));
+        //return (isPlayableFile(url.path()) || isAudioFile(url.path()));
+        return (isPlayableFile(url.path()) && _playlist->isMediaFile(url.path()));
     } else {
         // for a networked url, there is no way to know if it's playable right now
         return true;
@@ -114,62 +135,62 @@ bool PlayerEngine::isPlayableFile(const QUrl &url)
 
 static QStringList suffixes;
 
-static const QStringList &buildPlayableDatabase()
-{
-    static QStringList mimeTypes = {
-        "application/ogg",
-        "application/vnd.apple.mpegurl",
-        "application/vnd.rn-realmedia",
-        "application/x-extension-mp4",
-        "application/x-flac",
-        "application/x-matroska",
-        "application/x-ogg",
-        "application/xspf+xml",
-        "image/vnd.rn-realpix",
-        "misc/ultravox",
-        "video/3gpp",
-        "video/dv",
-        "video/mp2t",
-        "video/mp4",
-        "video/mp4v-es",
-        "video/mpeg",
-        "video/msvideo",
-        "video/ogg",
-        "video/quicktime",
-        "video/vnd.rn-realvideo",
-        "video/webm",
-        "video/x-anim",
-        "video/x-avi",
-        "video/x-flc",
-        "video/x-fli",
-        "video/x-flv",
-        "video/x-m4v",
-        "video/x-matroska",
-        "video/x-mpeg",
-        "video/x-mpeg2",
-        "video/x-ms-afs",
-        "video/x-ms-asf",
-        "video/x-msvideo",
-        "video/x-ms-wmv",
-        "video/x-ms-wmx",
-        "video/x-ms-wvxvideo",
-        "video/x-nsv",
-        "video/x-ogm+ogg",
-        "video/x-theora",
-        "video/x-theora+ogg",
-        "x-content/video-dvd",
-        "x-content/video-svcd",
-        "x-content/video-vcd",
-        "x-scheme-handler/mms",
-        "x-scheme-handler/rtmp",
-        "x-scheme-handler/rtsp",
-    };
+//static const QStringList &buildPlayableDatabase()
+//{
+//    static QStringList mimeTypes = {
+//        "application/ogg",
+//        "application/vnd.apple.mpegurl",
+//        "application/vnd.rn-realmedia",
+//        "application/x-extension-mp4",
+//        "application/x-flac",
+//        "application/x-matroska",
+//        "application/x-ogg",
+//        "application/xspf+xml",
+//        "image/vnd.rn-realpix",
+//        "misc/ultravox",
+//        "video/3gpp",
+//        "video/dv",
+//        "video/mp2t",
+//        "video/mp4",
+//        "video/mp4v-es",
+//        "video/mpeg",
+//        "video/msvideo",
+//        "video/ogg",
+//        "video/quicktime",
+//        "video/vnd.rn-realvideo",
+//        "video/webm",
+//        "video/x-anim",
+//        "video/x-avi",
+//        "video/x-flc",
+//        "video/x-fli",
+//        "video/x-flv",
+//        "video/x-m4v",
+//        "video/x-matroska",
+//        "video/x-mpeg",
+//        "video/x-mpeg2",
+//        "video/x-ms-afs",
+//        "video/x-ms-asf",
+//        "video/x-msvideo",
+//        "video/x-ms-wmv",
+//        "video/x-ms-wmx",
+//        "video/x-ms-wvxvideo",
+//        "video/x-nsv",
+//        "video/x-ogm+ogg",
+//        "video/x-theora",
+//        "video/x-theora+ogg",
+//        "x-content/video-dvd",
+//        "x-content/video-svcd",
+//        "x-content/video-vcd",
+//        "x-scheme-handler/mms",
+//        "x-scheme-handler/rtmp",
+//        "x-scheme-handler/rtsp",
+//    };
 
-    if (suffixes.isEmpty()) {
-    }
+//    if (suffixes.isEmpty()) {
+//    }
 
-    return suffixes;
-}
+//    return suffixes;
+//}
 
 bool PlayerEngine::isPlayableFile(const QString &name)
 {
@@ -204,7 +225,7 @@ void PlayerEngine::updateSubStyles()
         sz /= scale;
         /* magic scale number 2.0 comes from my mind, test with my eyes... */
         sz *= 2.0;
-        qDebug() << "update sub " << font << sz;
+        qInfo() << "update sub " << font << sz;
         updateSubStyle(font, sz);
     }
 #endif
@@ -246,7 +267,7 @@ void PlayerEngine::onBackendStateChanged()
     QString WAYLAND_DISPLAY = systemEnv.value(QStringLiteral("WAYLAND_DISPLAY"));
     if (XDG_SESSION_TYPE == QLatin1String("wayland") ||
             WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) {
-        if ( _state == CoreState::Idle) {
+        if (_state == CoreState::Idle) {
             QPalette pal(qApp->palette());
             this->setAutoFillBackground(true);
             this->setPalette(pal);
@@ -313,6 +334,9 @@ int PlayerEngine::sid()
 void PlayerEngine::onSubtitlesDownloaded(const QUrl &url, const QList<QString> &filenames,
                                          OnlineSubtitle::FailReason reason)
 {
+    //mod for warning by xxj ,no any means
+    reason = OnlineSubtitle::FailReason::NoError;
+
     if (state() == CoreState::Idle) {
         return;
     }
@@ -324,7 +348,7 @@ void PlayerEngine::onSubtitlesDownloaded(const QUrl &url, const QList<QString> &
     bool res = false;
 
     for (auto &filename : filenames) {
-        if ( true == _current->loadSubtitle(filename)) {
+        if (true == _current->loadSubtitle(filename)) {
             res = true;
         } else {
             QFile::remove(filename);
@@ -397,7 +421,12 @@ double PlayerEngine::subDelay() const
 
 QString PlayerEngine::subCodepage()
 {
-    return _current->subCodepage();
+    if (_current->subCodepage().isEmpty()) {
+        return "auto";
+    } else {
+        return _current->subCodepage();
+    }
+
 }
 
 void PlayerEngine::setSubCodepage(const QString &cp)
@@ -405,7 +434,7 @@ void PlayerEngine::setSubCodepage(const QString &cp)
     if (!_current) return;
     _current->setSubCodepage(cp);
 
-    emit subCodepageChanged();
+//    emit subCodepageChanged();
 }
 
 void PlayerEngine::addSubSearchPath(const QString &path)
@@ -484,13 +513,30 @@ bool PlayerEngine::muted() const
     return _current->muted();
 }
 
+void PlayerEngine::changehwaccelMode(Backend::hwaccelMode hwaccelMode)
+{
+    if (!_current) return;
+    return _current->changehwaccelMode(hwaccelMode);
+}
+
 void PlayerEngine::toggleMute()
 {
     if (!_current) return;
+    //发送信号通知初始化库函数
+    if (!m_bMpvFunsLoad) {
+        emit mpvFunsLoadOver();
+        m_bMpvFunsLoad = true;
+    }
+
     _current->toggleMute();
     emit volumeChanged();
 }
 
+void PlayerEngine::setMute(bool bMute)
+{
+    _current->setMute(bMute);
+}
+
 void PlayerEngine::savePreviousMovieState()
 {
     savePlaybackPosition();
@@ -498,16 +544,31 @@ void PlayerEngine::savePreviousMovieState()
 
 void PlayerEngine::paintEvent(QPaintEvent *e)
 {
-    if (!CompositingManager::get().composited()) {
-        QRect rect = this->rect();
-        QImage icon = utils::LoadHiDPIImage(":/resources/icons/light/init-splash.svg");
-        QPixmap pix = QPixmap::fromImage(icon);
-        int x = this->rect().center().x() - pix.width() / 2;
-        int y = this->rect().center().y() - pix.height() / 2;
-        QPainter p(this);
+    bool bIsMusic = false;
+    QRect rect = this->rect();
+    QPainter p(this);
 
-        p.fillRect(rect, QBrush(QColor(255, 255, 255)));
-        p.drawPixmap(x, y, pix);
+    if (_playlist->count() > 0 && _state != Idle) {
+        bIsMusic = isAudioFile(_playlist->currentInfo().mi.title);
+    }
+
+    if (!CompositingManager::get().composited()) {
+        if (_state != Idle && bIsMusic) {
+            p.fillRect(rect, QBrush(QColor(0, 0, 0)));
+        } else {
+            QImage icon = utils::LoadHiDPIImage(":/resources/icons/light/init-splash.svg");
+            QPixmap pix = QPixmap::fromImage(icon);
+            int x = this->rect().center().x() - pix.width() / 2;
+            int y = this->rect().center().y() - pix.height() / 2;
+
+            if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+                p.fillRect(rect, QBrush(QColor(255, 255, 255)));
+                p.drawPixmap(x, y, pix);
+            } else {
+                p.fillRect(rect, QBrush(QColor(0, 0, 0)));
+                p.drawPixmap(x, y, pix);
+            }
+        }
     }
     return QWidget::paintEvent(e);
 }
@@ -550,6 +611,10 @@ void PlayerEngine::previousFrame()
     if (!_current) return;
     _current->previousFrame();
 }
+void PlayerEngine::makeCurrent()
+{
+    _current->makeCurrent();
+}
 
 void PlayerEngine::play()
 {
@@ -594,8 +659,12 @@ void PlayerEngine::onPlaylistAsyncAppendFinished(const QList<PlayItemInfo> &pil)
         if (id >= 0) {
             _playlist->changeCurrent(id);
             _pendingPlayReq = QUrl();
+        } else {
+            qInfo() << __func__ << "id is:" << id;
         }
         // else, wait for another signal
+    } else {
+        qInfo() << __func__ << _pendingPlayReq;
     }
 }
 
@@ -603,6 +672,7 @@ void PlayerEngine::playByName(const QUrl &url)
 {
     savePreviousMovieState();
     auto id = _playlist->indexOf(url);
+    qInfo() << __func__ << url << "id:" << id;
     if (id >= 0) {
         _playlist->changeCurrent(id);
     } else {
@@ -612,6 +682,7 @@ void PlayerEngine::playByName(const QUrl &url)
 
 void PlayerEngine::playSelected(int id)
 {
+    qInfo() << __func__ << id;
     savePreviousMovieState();
     _playlist->changeCurrent(id);
 }
@@ -672,7 +743,7 @@ void PlayerEngine::seekBackward(int secs)
     if (state() == CoreState::Idle) return;
 
     if (elapsed() - abs(secs) <= 0) {
-        _current->seekBackward(elapsed());
+        _current->seekBackward(static_cast<int>(elapsed()));
     } else {
         _current->seekBackward(secs);
     }
@@ -694,8 +765,15 @@ void PlayerEngine::setDVDDevice(const QString &path)
     _current->setDVDDevice(path);
 }
 
+/*void PlayerEngine::firstInit()
+{
+    _current->firstInit();
+    addSubSearchPath(OnlineSubtitle::get().storeLocation());
+}*/
+
 bool PlayerEngine::addPlayFile(const QUrl &url)
 {
+    qInfo() << __func__;
     if (isPlayableFile(url)) {
         if (url.isLocalFile())
             _playlist->appendAsync({url});
@@ -717,12 +795,11 @@ QList<QUrl> PlayerEngine::collectPlayDir(const QDir &dir)
         di.next();
         if (di.fileInfo().isFile() && isPlayableFile(di.fileName())) {
             strtp = di.filePath();
-            while(QFileInfo(strtp).isSymLink())
-            {
+            while (QFileInfo(strtp).isSymLink()) {
                 /*****************************
                  * use oringnal path to replace link path
                  * ***************************/
-               strtp = QFileInfo(strtp).symLinkTarget();
+                strtp = QFileInfo(strtp).symLinkTarget();
             }
             urls.append(QUrl::fromLocalFile(strtp));
         }
@@ -741,21 +818,32 @@ QList<QUrl> PlayerEngine::addPlayDir(const QDir &dir)
 
 QList<QUrl> PlayerEngine::addPlayFiles(const QList<QUrl> &urls)
 {
+    qInfo() << __func__;
     QList<QUrl> valids = collectPlayFiles(urls);
+    for (auto &url : valids) {
+        QString strtp = url.toLocalFile();
+        while (QFileInfo(strtp).isSymLink()) {
+            /*****************************
+             * use oringnal path to replace link path
+             * ***************************/
+            strtp = QFileInfo(strtp).symLinkTarget();
+        }
+        url = QUrl::fromLocalFile(strtp);
+    }
     _playlist->appendAsync(valids);
     return valids;
 }
 
 QList<QUrl> PlayerEngine::collectPlayFiles(const QList<QUrl> &urls)
 {
-    qDebug() << urls;
+    qInfo() << urls;
     //NOTE: take care of loop, we don't recursive, it seems safe now
     QList<QUrl> valids;
     for (const auto &url : urls) {
         if (url.isLocalFile()) {
             QFileInfo fi(url.toLocalFile());
             if (!fi.exists()) {
-                qDebug() << url << "don't exist";
+                qInfo() << url << "don't exist";
                 continue;
             }
 
@@ -767,7 +855,7 @@ QList<QUrl> PlayerEngine::collectPlayFiles(const QList<QUrl> &urls)
             }
 
             if (!url.isValid() || !isPlayableFile(url)) {
-                qDebug() << url << "not valid or playable";
+                qInfo() << url << "not valid or playable";
                 continue;
             }
 
@@ -796,9 +884,9 @@ qint64 PlayerEngine::elapsed() const
     if (!_playlist) return 0;
     if (_playlist->count() == 0) return 0;
     if (_playlist->current() < 0) return 0;
-    qint64 nDuration = _playlist->items()[_playlist->current()].mi.duration;        //因为文件信息的持续时间和MPV返回的持续有些差别，所以，我们使用文件返回的持续时间
+    qint64 nDuration = _current->duration();        //因为文件信息的持续时间和MPV返回的持续有些差别，所以，我们使用文件返回的持续时间
     qint64 nElapsed = _current->elapsed();
-    if (nElapsed < 0 )
+    if (nElapsed < 0)
         return 0;
     if (nElapsed > nDuration)
         return nDuration;
@@ -835,16 +923,10 @@ void PlayerEngine::changeSoundMode(Backend::SoundMode sm)
         _current->changeSoundMode(sm);
 }
 
-void PlayerEngine::changeHwdecMode(Backend::HwdecMode hm)
+void PlayerEngine::resizeEvent(QResizeEvent *)
 {
-    if (_current)
-        _current->changeHwdecMode(hm);
-}
-void PlayerEngine::resizeEvent(QResizeEvent *re)
-{
-    bool rounded = !window()->isFullScreen() && !window()->isMaximized();
-
 #if !defined(USE_DXCB) && !defined(_LIBDMR_)
+    bool rounded = !window()->isFullScreen() && !window()->isMaximized();
     if (rounded) {
         QPixmap shape(size());
         shape.fill(Qt::transparent);
@@ -880,11 +962,11 @@ QVariant PlayerEngine::getBackendProperty(const QString &name)
     return QVariant();
 }
 
-void PlayerEngine::setVideoZoom(float val)
+/*void PlayerEngine::setVideoZoom(float val)
 {
     if (_current) {
         _current->setProperty("video-zoom", val);
     }
-}
+}*/
 
 } // end of namespace dmr
