@@ -66,12 +66,10 @@ public:
     Q_ENUM(CoreState)
 
     // filetypes supported by mpv: https://github.com/mpv-player/mpv/blob/master/player/external_files.c
-    const QStringList audio_filetypes {"*.mp3", "*.ogg", "*.wav", "*.wma", "*.m4a", "*.aac", "*.ac3", "*.ape", "*.flac", "*.ra", "*.mka", "*.dts", "*.opus"};
-    const QStringList video_filetypes {
-        "*.3g2", "*.3ga", "*.3gp", "*.3gp2", "*.3gpp", "*.amv", "*.asf", "*.asx", "*.avf", "*.avi", "*.bdm", "*.bdmv", "*.bik", "*.clpi", "*.cpi", "*.dat", "*.divx", "*.drc", "*.dv", "*.dvr-ms", "*.f4v", "*.flv", "*.gvi", "*.gxf", "*.hdmov", "*.hlv", "*.iso", "*.letv", "*.lrv", "*.m1v", "*.m2p", "*.m2t", "*.m2ts", "*.m2v", "*.m3u", "*.m3u8", "*.m4v", "*.mkv", "*.moov", "*.mov", "*.mov", "*.mp2", "*.mp2v", "*.mp4", "*.mp4v", "*.mpe", "*.mpeg", "*.mpeg1", "*.mpeg2", "*.mpeg4", "*.mpg", "*.mpl", "*.mpls", "*.mpv", "*.mpv2", "*.mqv", "*.mts", "*.mts", "*.mtv", "*.mxf", "*.mxg", "*.nsv", "*.nuv", "*.ogg", "*.ogm", "*.ogv", "*.ogx", "*.ps", "*.qt", "*.qtvr", "*.ram", "*.rec", "*.rm", "*.rm", "*.rmj", "*.rmm", "*.rms", "*.rmvb", "*.rmx", "*.rp", "*.rpl", "*.rv", "*.rvx", "*.thp", "*.tod", "*.tp", "*.trp", "*.ts", "*.tts", "*.txd", "*.vcd", "*.vdr", "*.vob", "*.vp8", "*.vro", "*.webm", "*.wm", "*.wmv", "*.wtv", "*.xesc", "*.xspf"
-    };
+    const static QStringList audio_filetypes;
+    const static QStringList video_filetypes;
 
-    const QStringList subtitle_suffixs {"ass", "sub", "srt", "aqt", "jss", "gsub", "ssf", "ssa", "smi", "usf", "idx"};
+    const static QStringList subtitle_suffixs;
 
     /* backend like mpv will asynchronously report end of playback.
      * there are situations when we need to see the end-event before
@@ -81,11 +79,14 @@ public:
 
     friend class PlaylistModel;
 
-    PlayerEngine(QWidget *parent = 0);
+    explicit PlayerEngine(QWidget *parent);
     virtual ~PlayerEngine();
 
     // only the last dvd device set
     void setDVDDevice(const QString &path);
+    //add by heyi
+    //第一次播放需要初库始化函数指针
+    void firstInit();
 
     bool addPlayFile(const QUrl &url);
     QList<QUrl> addPlayDir(const QDir &dir); // return collected valid urls
@@ -94,7 +95,7 @@ public:
 
     bool isPlayableFile(const QUrl &url);
     bool isPlayableFile(const QString &name);
-    bool isAudioFile(const QString &name);
+    static bool isAudioFile(const QString &name);
 
     // only supports (+/-) 0, 90, 180, 270
     int videoRotation() const;
@@ -130,10 +131,11 @@ public:
     int aid();
 
     void changeSoundMode(Backend::SoundMode sm);
-    void changeHwdecMode(Backend::HwdecMode hm);
     int volume() const;
     bool muted() const;
 
+    void changehwaccelMode(Backend::hwaccelMode hwaccelMode);
+
     PlaylistModel &playlist() const
     {
         return *_playlist;
@@ -151,12 +153,14 @@ public:
 
     void nextFrame();
     void previousFrame();
+    //只在wayland下opengl窗口使用
+    void makeCurrent();
 
     // use with caution
     void setBackendProperty(const QString &, const QVariant &);
     QVariant getBackendProperty(const QString &);
 
-    void setVideoZoom(float);
+//    void setVideoZoom(float);
 
 signals:
     void tracksChanged();
@@ -171,6 +175,8 @@ signals:
     void subCodepageChanged();
 
     void loadOnlineSubtitlesFinished(const QUrl &url, bool success);
+    //add by heyi mpv函数加载完毕
+    void mpvFunsLoadOver();
 
     //emit during burst screenshotting
     void notifyScreenshot(const QImage &frame, qint64 time);
@@ -183,6 +189,7 @@ signals:
     void urlpause(bool status);
 
     void siginitthumbnailseting();
+    void updateDuration();
 
 public slots:
     void play();
@@ -203,6 +210,7 @@ public slots:
     void volumeDown();
     void changeVolume(int val);
     void toggleMute();
+    void setMute(bool bMute);
 
 protected slots:
     void onBackendStateChanged();
@@ -220,11 +228,13 @@ protected:
     QUrl _pendingPlayReq;
 
     bool _playingRequest {false};
+    //add by heyi
+    bool m_bMpvFunsLoad {false};
 
     QList<QUrl> collectPlayFiles(const QList<QUrl> &urls);
     QList<QUrl> collectPlayDir(const QDir &dir);
 
-    void resizeEvent(QResizeEvent *re) override;
+    void resizeEvent(QResizeEvent *) override;
     void savePreviousMovieState();
 
     void paintEvent(QPaintEvent *e) override;
