@@ -1,5 +1,9 @@
 /*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     zhuyuliang <zhuyuliang@uniontech.com>
+ *
+ * Maintainer: xiepengfei <xiepengfei@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,11 +34,14 @@
 #include "utils.h"
 #include <QtDBus>
 #include <QtWidgets>
+#include <QPainterPath>
 
 namespace dmr {
 namespace utils {
 using namespace std;
 
+static bool isWayland = false;
+
 void ShowInFileManager(const QString &path)
 {
     if (path.isEmpty() || !QFile::exists(path)) {
@@ -47,12 +54,16 @@ void ShowInFileManager(const QString &path)
     query.addQueryItem("selectUrl", QUrl::fromLocalFile(path).toString());
     url.setQuery(query);*/
 
-    qDebug() << __func__ << url.toString();
+    qInfo() << __func__ << url.toString();
 
     // Try dde-file-manager
     QProcess *fp = new QProcess();
     QObject::connect(fp, SIGNAL(finished(int)), fp, SLOT(deleteLater()));
+#ifndef USE_TEST
     fp->start("dde-file-manager", QStringList(url.toString()));
+#else
+    fp->start("wrong-name-for-test", QStringList(url.toString()));
+#endif
     fp->waitForStarted(3000);
 
     if (fp->error() == QProcess::FailedToStart) {
@@ -64,21 +75,20 @@ void ShowInFileManager(const QString &path)
         if (iface.isValid()) {
             // Convert filepath to URI first.
             const QStringList uris = { QUrl::fromLocalFile(path).toString() };
-            qDebug() << "freedesktop.FileManager";
+            qInfo() << "freedesktop.FileManager";
             // StartupId is empty here.
             QDBusPendingCall call = iface.asyncCall("ShowItems", uris, "");
             Q_UNUSED(call);
         }
         // Try to launch other file manager if nautilus is invalid
         else {
-            qDebug() << "desktopService::openUrl";
+            qInfo() << "desktopService::openUrl";
             QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(path).dir().absolutePath()));
         }
         fp->deleteLater();
     }
 }
 
-
 static int min(int v1, int v2, int v3)
 {
     return std::min(v1, std::min(v2, v3));
@@ -89,25 +99,25 @@ static int stringDistance(const QString &s1, const QString &s2)
     int n = s1.size(), m = s2.size();
     if (!n || !m) return max(n, m);
 
-    vector<int> dp(n + 1);
-    for (int i = 0; i < n + 1; i++) dp[i] = i;
-    int pred = 0;
+    vector<int> dp(static_cast<vector<int>::size_type>(n + 1));
+    for (int i = 0; i < n + 1; i++) dp[static_cast<vector<int>::size_type>(i)] = i;
+//    int pred = 0;
     int curr = 0;
 
     for (int i = 0; i < m; i++) {
         dp[0] = i;
-        pred = i + 1;
+        int pred = i + 1;
         for (int j = 0; j < n; j++) {
             if (s1[j] == s2[i]) {
-                curr = dp[j];
+                curr = dp[static_cast<vector<int>::size_type>(j)];
             } else {
-                curr = min(dp[j], dp[j + 1], pred) + 1;
+                curr = min(dp[static_cast<vector<int>::size_type>(j)], dp[static_cast<vector<int>::size_type>(j + 1)], pred) + 1;
             }
-            dp[j] = pred;
+            dp[static_cast<vector<int>::size_type>(j)] = pred;
             pred = curr;
 
         }
-        dp[n] = pred;
+        dp[static_cast<vector<int>::size_type>(n)] = pred;
     }
 
     return curr;
@@ -156,7 +166,7 @@ bool CompareNames(const QString &fileName1, const QString &fileName2)
         auto pos2 = rd.indexIn(fileName2, pos);
         if (pos == pos2) {
             auto id2 = fileName2.midRef(pos, rd.matchedLength());
-            //qDebug() << "id compare " << id1 << id2;
+            //qInfo() << "id compare " << id1 << id2;
             if (id1 != id2) {
                 bool ok1, ok2;
                 bool v = id1.toInt(&ok1) < id2.toInt(&ok2);
@@ -170,6 +180,32 @@ bool CompareNames(const QString &fileName1, const QString &fileName2)
     return fileName1.localeAwareCompare(fileName2) < 0;
 }
 
+bool first_check_wayland_env()
+{
+    auto e = QProcessEnvironment::systemEnvironment();
+    QString XDG_SESSION_TYPE = e.value(QStringLiteral("XDG_SESSION_TYPE"));
+    QString WAYLAND_DISPLAY = e.value(QStringLiteral("WAYLAND_DISPLAY"));
+
+    if (XDG_SESSION_TYPE == QLatin1String("wayland") || WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) {
+        isWayland = true;
+        return true;
+    } else {
+        return false;
+    }
+}
+
+bool check_wayland_env()
+{
+    return isWayland;
+}
+
+#ifdef USE_TEST
+void set_wayland(bool _b)
+{
+    isWayland = _b;
+}
+#endif
+
 // hash the whole file takes amount of time, so just pick some areas to be hashed
 QString FastFileHash(const QFileInfo &fi)
 {
@@ -195,6 +231,7 @@ QString FastFileHash(const QFileInfo &fi)
         bytes += f.read(4096);
 
     });
+    f.close();
 
     return QString(QCryptographicHash::hash(bytes, QCryptographicHash::Md5).toHex());
 }
@@ -202,14 +239,13 @@ QString FastFileHash(const QFileInfo &fi)
 // hash the entire file (hope file is small)
 QString FullFileHash(const QFileInfo &fi)
 {
-    auto sz = fi.size();
-
     QFile f(fi.absoluteFilePath());
     if (!f.open(QFile::ReadOnly)) {
         return QString();
     }
 
     auto bytes = f.readAll();
+    f.close();
     return QString(QCryptographicHash::hash(bytes, QCryptographicHash::Md5).toHex());
 }
 
@@ -272,10 +308,10 @@ QPixmap MakeRoundedPixmap(QSize sz, QPixmap pm, qreal rx, qreal ry, qint64 time)
     ft.setWeight(QFont::Medium);
     p.setFont(ft);
 
-    auto tm_str = QTime(0, 0, 0).addSecs(time).toString("hh:mm:ss");
+    auto tm_str = QTime(0, 0, 0).addSecs(static_cast<int>(time)).toString("hh:mm:ss");
     QRect bounding = QFontMetrics(ft).boundingRect(tm_str);
-    bounding.moveTopLeft({((int)(dest.width() / dpr)) - 5 - bounding.width(),
-                          ((int)(dest.height() / dpr)) - 5 - bounding.height()});
+    bounding.moveTopLeft({(static_cast<int>(dest.width() / dpr)) - 5 - bounding.width(),
+                          (static_cast<int>(dest.height() / dpr)) - 5 - bounding.height()});
 
     {
         QPainterPath pp;
@@ -307,7 +343,7 @@ uint32_t InhibitStandby()
         return reply.value();
     }
 
-    qDebug() << reply.error().message();
+    qInfo() << reply.error().message();
     return 0;
 }
 
@@ -330,7 +366,7 @@ uint32_t InhibitPower()
         return reply.value();
     }
 
-    qDebug() << reply.error().message();
+    qInfo() << reply.error().message();
     return 0;
 }
 
@@ -353,8 +389,16 @@ void MoveToCenter(QWidget *w)
 QString Time2str(qint64 seconds)
 {
     QTime d(0, 0, 0);
-    d = d.addSecs(seconds);
-    return d.toString("hh:mm:ss");
+    if (seconds < DAYSECONDS) {
+        d = d.addSecs(static_cast<int>(seconds));
+        return d.toString("hh:mm:ss");
+    } else {
+        d = d.addSecs(static_cast<int>(seconds));
+        int add = static_cast<int>(seconds / DAYSECONDS) * 24;
+        QString dayOut =  d.toString("hh:mm:ss");
+        dayOut.replace(0, 2, QString::number(add + dayOut.left(2).toInt()));
+        return dayOut;
+    }
 }
 
 QString videoIndex2str(int index)
@@ -436,7 +480,8 @@ QString audioIndex2str(int index)
     return aa;
 }
 
-QString subtitleIndex2str(int index)
+///not used///
+/*QString subtitleIndex2str(int index)
 {
     QStringList subtitleList1 = {"dvd_subtitle", "dvb_subtitle", "text", "xsub", "ssa",
                                  "mov_text", "hdmv_pgs_subtitle", "dvb_teletext", "srt"
@@ -452,8 +497,9 @@ QString subtitleIndex2str(int index)
         codecMap.insert(i + 96256, subtitleList2[i]);
     }
     return codecMap[index];
-}
+}*/
 
+//cppcheck 单元测试在用
 bool ValidateScreenshotPath(const QString &path)
 {
     auto name = path.trimmed();
@@ -542,5 +588,32 @@ QString ElideText(const QString &text, const QSize &size,
     return str;
 }
 
+void getPlayProperty(const char *path, QMap<QString, QString> *&proMap)
+{
+    QFileInfo fi(path);
+    if ((fi.exists() && fi.isFile()) && fi.isReadable()) {
+        QFile file(path);
+        if (file.open(QIODevice::ReadOnly) | QIODevice::Text) {
+            QByteArray t;
+            int index = 0;
+            while (!file.atEnd()) {
+                t = file.readLine();
+                QList<QByteArray> list = t.split('=');
+                index++;
+                if (2 == list.size()) {
+                    QString temp = list.back();
+                    temp = temp.mid(0, temp.length() - 1);//去除/n
+                    proMap->insert(list.first(), temp);
+                } else {
+                    qWarning() << __func__ << QString("config line:%1 has error ").arg(index);
+                    continue;
+                }
+            }
+        }
+        file.close();
+    } else {
+        qWarning() << __func__ << "file path error!!!!!";
+    }
+}
 }
 }
