@@ -1,5 +1,9 @@
 /*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     zhuyuliang <zhuyuliang@uniontech.com>
+ *
+ * Maintainer: xiepengfei <xiepengfei@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -51,69 +55,116 @@
 #include "vendor/presenter.h"
 #include <QSettings>
 
+
+#include <stdio.h>
+#include <unistd.h>
+#include <fcntl.h>
+
+#include "accessibility/acobjectlist.h"
 DWIDGET_USE_NAMESPACE
 
+bool runSingleInstance()
+{
+    QString userName = QDir::homePath().section("/", -1, -1);
+    std::string path = ("/home/" + userName + "/.cache/deepin/deepin-movie/").toStdString();
+    QDir tdir(path.c_str());
+    if (!tdir.exists()) {
+        tdir.mkpath(path.c_str());
+    }
+
+    path += "single";
+    int fd = open(path.c_str(), O_WRONLY | O_CREAT, 0644);
+    int flock = lockf(fd, F_TLOCK, 0);
+
+    if (fd == -1) {
+        qInfo() << strerror(errno);
+        return false;
+    }
+    if (flock == -1) {
+        qInfo() << strerror(errno);
+        return false;
+    }
+    return true;
+}
+
 
 int main(int argc, char *argv[])
 {
-    setenv("PULSE_PROP_media.role", "video", 1);
-
+#ifdef __aarch64__
+    if (dmr::utils::first_check_wayland_env()) {
+        qputenv("QT_WAYLAND_SHELL_INTEGRATION", "kwayland-shell");
+        //qputenv("_d_disableDBusFileDialog", "true");
+        setenv("PULSE_PROP_media.role", "video", 1);
+        QSurfaceFormat format;
+        format.setRenderableType(QSurfaceFormat::OpenGLES);
+        format.setDefaultFormat(format);
+    }
+#endif
 #ifdef __mips__
     if (CompositingManager::get().composited()) {
         CompositingManager::detectOpenGLEarly();
         CompositingManager::detectPciID();
     }
-#else
-    CompositingManager::detectOpenGLEarly();
-    CompositingManager::detectPciID();
 #endif
-
 #if defined(STATIC_LIB)
     DWIDGET_INIT_RESOURCE();
 #endif
+    /**
+      *This function dtk is obsolete and has no
+      * impact after testing on x86 platform.
+      * If there is a problem with later adaptation,
+      * please give priority to whether there
+      * is any impact here.
+      */
+//    DApplication::loadDXcbPlugin();
+    DApplication *app = nullptr;
+#if (DTK_VERSION < DTK_VERSION_CHECK(5, 4, 0, 0))
+    app = new DApplication(argc, argv);
+#else
+    app = DApplication::globalApplication(argc, argv);
+#endif
 
-    DApplication::loadDXcbPlugin();
-
-    DApplication app(argc, argv);
-
+    QAccessible::installFactory(accessibleFactory);
     // required by mpv
     setlocale(LC_NUMERIC, "C");
 
 #ifdef __mips__
     if (CompositingManager::get().composited()) {
-        app.setAttribute(Qt::AA_UseHighDpiPixmaps);
+        app->setAttribute(Qt::AA_UseHighDpiPixmaps);
         // overwrite DApplication default value
-        app.setAttribute(Qt::AA_ForceRasterWidgets, false);
+        app->setAttribute(Qt::AA_ForceRasterWidgets, false);
     }
 #else
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps);
+    app->setAttribute(Qt::AA_UseHighDpiPixmaps);
     // overwrite DApplication default value
-    app.setAttribute(Qt::AA_ForceRasterWidgets, false);
+    app->setAttribute(Qt::AA_ForceRasterWidgets, false);
 #endif
 
-    app.setOrganizationName("deepin");
-    app.setApplicationName("deepin-movie");
-    app.setApplicationVersion(DMR_VERSION);
-    app.setProductIcon(utils::LoadHiDPIPixmap(":/resources/icons/logo-big.svg"));
-    app.setWindowIcon(QIcon(":/resources/icons/logo-big.svg"));
+    app->setOrganizationName("deepin");
+    app->setApplicationName("deepin-movie");
+    app->setApplicationVersion(DMR_VERSION);
+    app->setProductIcon(utils::LoadHiDPIPixmap(":/resources/icons/logo-big.svg"));
+    app->setWindowIcon(QIcon(":/resources/icons/logo-big.svg"));
     QString acknowledgementLink = "https://www.deepin.org/acknowledgments/deepin-movie";
-    app.setApplicationAcknowledgementPage(acknowledgementLink);
+    app->setApplicationAcknowledgementPage(acknowledgementLink);
 
     //save theme
     DApplicationSettings saveTheme;
+
+    qInfo() << "log path: " << Dtk::Core::DLogManager::getlogFilePath();
     auto &clm = dmr::CommandLineManager::get();
-    clm.process(app);
+    clm.process(*app);
 
     QStringList toOpenFiles;
     if (clm.positionalArguments().length() > 0) {
         toOpenFiles = clm.positionalArguments();
     }
 
-    app.loadTranslator();
-    app.setApplicationDisplayName(QObject::tr("Movie"));
-    app.setApplicationDescription(QObject::tr(
-                                      "Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats."
-                                  ));
+    app->loadTranslator();
+    app->setApplicationDisplayName(QObject::tr("Movie"));
+    app->setApplicationDescription(QObject::tr(
+                                       "Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats."
+                                   ));
 //    "Deepin Movie is a well-designed and full-featured"
 //    " video player with simple borderless design. It supports local and"
 //    " streaming media play with multiple video formats."
@@ -124,39 +175,35 @@ int main(int argc, char *argv[])
         Dtk::Core::DLogManager::registerConsoleAppender();
     }
     Dtk::Core::DLogManager::registerFileAppender();
-    qInfo() << "log path: " << Dtk::Core::DLogManager::getlogFilePath();
 
     bool singleton = !dmr::Settings::get().isSet(dmr::Settings::MultipleInstance);
 
-    QString strUserPath = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
-
-    QSharedMemory shared_memory(strUserPath + "deepinmovie");
-
-    if (shared_memory.attach()) {
-        shared_memory.detach();
-    }
-
-    if (singleton && !shared_memory.create(1)) {
-        qWarning() << "another deepin movie instance has started";
+    if (singleton && !runSingleInstance()) {
+        qInfo() << "another deepin movie instance has started";
         if (!toOpenFiles.isEmpty()) {
             QDBusInterface iface("com.deepin.movie", "/", "com.deepin.movie");
             if (toOpenFiles.size() == 1) {
-                iface.asyncCall("openFile", toOpenFiles[0]);
+                if (!toOpenFiles[0].contains("QProcess"))
+                    iface.asyncCall("openFile", toOpenFiles[0]);
             } else {
                 iface.asyncCall("openFiles", toOpenFiles);
             }
         }
 
+        QDBusInterface iface("com.deepin.movie", "/", "com.deepin.movie");
+        if (iface.isValid()) {
+            qWarning() << "deepin-movie raise";
+            iface.asyncCall("Raise");
+        }
         exit(0);
     }
 
-
 //    app.setWindowIcon(QIcon(":/resources/icons/logo.svg"));
-    app.setApplicationDisplayName(QObject::tr("Movie"));
-    app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
+    app->setApplicationDisplayName(QObject::tr("Movie"));
+    app->setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
 
 //    app.setApplicationVersion(DApplication::buildVersion("20190830"));
-    app.setApplicationVersion(DApplication::buildVersion(VERSION));
+    app->setApplicationVersion(DApplication::buildVersion(VERSION));
     MovieConfiguration::get().init();
 
     QRegExp url_re("\\w+://");
@@ -164,9 +211,17 @@ int main(int argc, char *argv[])
     dmr::MainWindow mw;
     Presenter *presenter = new Presenter(&mw);
 //    mw.setMinimumSize(QSize(1070, 680));
-    mw.resize(850, 600);
-    utils::MoveToCenter(&mw);
-    mw.show();
+    mw.setPresenter(presenter);
+    if (CompositingManager::isPadSystem()) {
+        ///平板模式下全屏显示
+        mw.showMaximized();
+    } else {
+        mw.resize(850, 600);
+        utils::MoveToCenter(&mw);
+        mw.show();
+    }
+
+    mw.setOpenFiles(toOpenFiles);
 
     if (!QDBusConnection::sessionBus().isConnected()) {
         qWarning() << "dbus disconnected";
@@ -176,14 +231,14 @@ int main(int argc, char *argv[])
     QDBusConnection::sessionBus().registerService("com.deepin.movie");
     QDBusConnection::sessionBus().registerObject("/", &mw);
 
-    if (!toOpenFiles.isEmpty()) {
-        if (toOpenFiles.size() == 1) {
-            mw.play(toOpenFiles[0]);
-        } else {
-            mw.playList(toOpenFiles);
-        }
-    }
-    return app.exec();
+//    if (!toOpenFiles.isEmpty()) {
+//        if (toOpenFiles.size() == 1) {
+//            mw.play(toOpenFiles[0]);
+//        } else {
+//            mw.playList(toOpenFiles);
+//        }
+//    }
+    return app->exec();
 
 }
 
