@@ -27,6 +27,10 @@
  * version.  If you delete this exception statement from all source
  * files in the program, then also delete it here.
  */
+/**
+ * @file
+ * 此文件为影院播放截图相关。
+ */
 #ifndef _DMR_BURST_SCREENSHOTS_DIALOG_H
 #define _DMR_BURST_SCREENSHOTS_DIALOG_H
 
@@ -39,42 +43,72 @@ DWIDGET_USE_NAMESPACE
 namespace dmr {
 class PlayItemInfo;
 
+/**
+ * @brief The ThumbnailFrame class
+ * 单个截图图像窗口
+ */
 class ThumbnailFrame: public QLabel
 {
     Q_OBJECT
 public:
-    ThumbnailFrame(QWidget *parent) : QLabel(parent)
+    /**
+     * @brief ThumbnailFrame 构造函数
+     * @param parent 父窗口
+     */
+    explicit ThumbnailFrame(QWidget *parent) : QLabel(parent)
     {
+        //参考设计图
         setFixedSize(178, 100);
-        auto e = new QGraphicsDropShadowEffect(this);
-        e->setColor(QColor(0, 0, 0, 255 * 2 / 10));
-        e->setOffset(0, 2);
-        e->setBlurRadius(4);
-        setGraphicsEffect(e);
+        QGraphicsDropShadowEffect *pGraphicsShadow = new QGraphicsDropShadowEffect(this);
+        pGraphicsShadow->setColor(QColor(0, 0, 0, 255 * 2 / 10));
+        //参考设计图
+        pGraphicsShadow->setOffset(0, 2);
+        //参考设计图
+        pGraphicsShadow->setBlurRadius(4);
+        setGraphicsEffect(pGraphicsShadow);
     }
 };
 
-
+/**
+ * @brief The BurstScreenshotsDialog class
+ * 截图窗口
+ */
 class BurstScreenshotsDialog: public DAbstractDialog
 {
     Q_OBJECT
 public:
-    BurstScreenshotsDialog(const PlayItemInfo &pif);
+    /**
+     * @brief BurstScreenshotsDialog 构造函数
+     * @param strPlayItemInfo 播放项信息
+     */
+    explicit BurstScreenshotsDialog(const PlayItemInfo &strPlayItemInfo);
+    /**
+     * @brief updateWithFrames 更新截图图像
+     * @param frames 截图图像
+     */
     void updateWithFrames(const QList<QPair<QImage, qint64>> &frames);
-
+    /**
+     * @brief savedPosterPath 保存截图路径
+     * @return 返回设置的截图保存路径
+     */
     QString savedPosterPath();
 
 public slots:
+    /**
+     * @brief exec 返回执行函数的标识符
+     * @return 执行函数的标识符
+     */
     int exec() override;
-    void saveShootings();
+    /**
+     * @brief savePoster 保存截图
+     */
     void savePoster();
 
 private:
-    QGridLayout *_grid {nullptr};
-    QPushButton *_saveBtn {nullptr};
-    QList<QPair<QImage, qint64>> _thumbs;
-    QString _posterPath;
-    DTitlebar *m_titlebar;
+    QGridLayout             *m_pGrid;       ///截图窗口布局
+    QPushButton             *m_pSaveBtn;    ///截图保存按键
+    QString                  m_sPosterPath; ///截图保存路径
+    DTitlebar               *m_pTitlebar;   ///截图窗口标题栏
 };
 }
 
