@@ -1,5 +1,9 @@
-/* 
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+/*
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     xiangxiaojun <xiangxiaoju@uniontech.com>
+ *
+ * Maintainer: liuzheng <liuzheng@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,47 +31,60 @@
  * version.  If you delete this exception statement from all source
  * files in the program, then also delete it here.
  */
+/**
+ * @file
+ * 此文件为打开url时的输入框。
+ */
 #include "dmr_lineedit.h"
 
 namespace dmr {
-
-LineEdit::LineEdit(QWidget* parent)
-    :QLineEdit(parent)
+/**
+ * @brief LineEdit 构造函数
+ * @param parent 父窗口
+ */
+LineEdit::LineEdit(QWidget *parent)
+    : QLineEdit(parent)
 {
+    //参考设计图
     setFixedHeight(30);
-//    setStyleSheet(R"(
-//	QLineEdit {
-//        font-size: 11px;
-//		border-radius: 3px;
-//		background-color: #ffffff;
-//		border: 1px solid rgba(0, 0, 0, 0.08);
-//        color: #303030;
-//	}
-//    )");
 
     QIcon icon;
     icon.addFile(":/resources/icons/input_clear_normal.svg", QSize(), QIcon::Normal);
     icon.addFile(":/resources/icons/input_clear_press.svg", QSize(), QIcon::Selected);
     icon.addFile(":/resources/icons/input_clear_hover.svg", QSize(), QIcon::Active);
-    _clearAct = new QAction(icon, "", this);
+    m_pClearAct = new QAction(icon, "", this);
 
-    connect(_clearAct, &QAction::triggered, this, &QLineEdit::clear);
-    connect(this, &QLineEdit::textChanged, [=](const QString& s) {
-        if (s.isEmpty()) {
-            removeAction(_clearAct);
-        } else {
-            addAction(_clearAct, QLineEdit::TrailingPosition);
-        }
-    });
+    connect(m_pClearAct, &QAction::triggered, this, &QLineEdit::clear);
+	connect(this, &QLineEdit::textChanged, this, &LineEdit::slotTextChanged);
 
 }
-
-void LineEdit::showEvent(QShowEvent* se)
+/**
+ * @brief showEvent 重载显示事件
+ * @param pShowEvent 显示事件
+ */
+void LineEdit::showEvent(QShowEvent *pShowEvent)
 {
+    QLineEdit::showEvent(pShowEvent);
 }
-
-void LineEdit::resizeEvent(QResizeEvent* re)
+/**
+ * @brief resizeEvent 重载界面大小改变事件
+ * @param pResizeEvent 界面大小改变事件
+ */
+void LineEdit::resizeEvent(QResizeEvent *pResizeEvent)
 {
+    QLineEdit::resizeEvent(pResizeEvent);
+}
+/**
+ * @brief slotTextChanged 文本变化槽函数
+ * @param sText 输入框内的文本
+ */
+void LineEdit::slotTextChanged(const QString &sText)
+{
+    if (sText.isEmpty()) {
+        removeAction(m_pClearAct);
+    } else {
+        addAction(m_pClearAct, QLineEdit::TrailingPosition);
+    }
 }
 
 }
