@@ -42,6 +42,7 @@
 #include <DStyle>
 #include <DLabel>
 #include <DTextEdit>
+#include <QPainterPath>
 
 
 namespace Dtk {
@@ -65,56 +66,98 @@ public:
         setFixedSize(QSize(42, 24));
         _pic = pic;
     }
+    void setPic(QPixmap pic)
+    {
+        _pic = pic;
+    }
 protected:
     void paintEvent(QPaintEvent *pe) override
     {
-        QPainter painter(this);
-//        QBrush bgColor = QBrush(_pic);
-//        QPainterPath pp;
-//        QRectF bgRect;
-//        bgRect.setSize(size());
-//        pp.addRoundedRect(bgRect, 4, 4);
-//        painter.fillPath(pp, bgColor);
-        painter.save();
-        painter.setRenderHints(QPainter::HighQualityAntialiasing);
-        painter.setRenderHints(QPainter::SmoothPixmapTransform);
-        painter.setRenderHints(QPainter::Antialiasing);
+        /*        QPainter painter(this);
+                QBrush bgColor = QBrush(_pic);
+                QPainterPath pp;
+                QRectF bgRect;
+                bgRect.setSize(size());
+                painter.setRenderHint(QPainter::Antialiasing,true);
+                painter.setRenderHint(QPainter::SmoothPixmapTransform);
+                pp.addRoundedRect(bgRect, 3, 3);
+                painter.fillPath(pp, bgColor);
 
+                QPen pen;
+                pen.setWidth(2);
+                QColor borderColor(234,234,234);
+        //        borderColor.setAlphaF(0.1);
+                pen.setColor(borderColor);
+                pen.setStyle(Qt::SolidLine);
+        //        pen.setCapStyle(Qt::RoundCap);
+                painter.setPen(pen);
+                painter.drawPath(pp);
+        */
+
+        /*        QPainter painter(this);
+                painter.setRenderHints(QPainter::HighQualityAntialiasing | QPainter::SmoothPixmapTransform |
+                                       QPainter::Antialiasing);
+                QSize size(_pic.size());
+                QBitmap mask(size);
+                QPainter painter1(&mask);
+                painter1.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
+                painter1.fillRect(mask.rect(), Qt::white);
+                painter1.setBrush(QColor(0, 0, 0));
+                painter1.drawRoundedRect(mask.rect(), 4, 4);
+                QPixmap image = _pic;
+                image.setMask(mask);
+
+                painter.drawPixmap(rect(), image);
+
+                QPen pen;
+                pen.setWidth(2);
+                if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+                    pen.setColor(QColor(234, 234, 234));
+                    painter.setPen(pen);
+                } else if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+                    pen.setColor(QColor(255, 255, 255, 0.2 * 255));
+                    painter.setPen(pen);
+                }
+                painter.setBrush(Qt::NoBrush);
+                painter.drawRoundedRect(rect(), 4, 4);
+        */
+
+
+        QPainter painter(this);
+        painter.setRenderHints(QPainter::HighQualityAntialiasing | QPainter::SmoothPixmapTransform |
+                               QPainter::Antialiasing);
         QSize size(_pic.size());
         QBitmap mask(size);
         QPainter painter1(&mask);
-        painter1.setRenderHint(QPainter::Antialiasing);
-        painter1.setRenderHint(QPainter::SmoothPixmapTransform);
+        painter1.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
         painter1.fillRect(mask.rect(), Qt::white);
         painter1.setBrush(QColor(0, 0, 0));
-        painter1.drawRoundedRect(mask.rect(), 2, 2);
+        painter1.drawRoundedRect(mask.rect(), 5, 5);
         QPixmap image = _pic;
         image.setMask(mask);
 
+        painter.setClipping(true);
+        QPainterPath bg0;
+        bg0.addRoundedRect(rect(), 5, 5);   //使用5个像素点，圆角效果更好
+        painter.setClipPath(bg0);
+
         painter.drawPixmap(rect(), image);
 
-        QPen pen;
-        pen.setWidth(1);
-        if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
-            pen.setColor(QColor(0, 0, 0, 0.2 * 255));
-            painter.setPen(pen);
-        } else if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
-            pen.setColor(QColor(255, 255, 255, 0.2 * 255));
-            painter.setPen(pen);
-        }
+        painter.setPen(
+            QPen(DGuiApplicationHelper::instance()->applicationPalette().frameBorder().color(), 2));
         painter.setBrush(Qt::NoBrush);
-        painter.drawRoundedRect(rect(), 6, 6);
-        painter.restore();
+        painter.drawRoundedRect(rect(), 5, 5);
     };
 private:
     QPixmap _pic;
 };
 
-class FloatingButton: public DPushButton
+///be replaced by DFloatingButton
+/*class FloatingButton: public DPushButton
 {
     Q_OBJECT
 public:
-    FloatingButton(QWidget *p = nullptr) {}
+    explicit FloatingButton(QWidget *p = nullptr) {}
     virtual ~FloatingButton() {}
 
 protected:
@@ -131,6 +174,7 @@ protected:
 signals:
     void mouseHover(bool bFlag);
 };
+*/
 
 class PlayItemWidget;
 
@@ -142,8 +186,10 @@ public:
         Opened,
         Closed,
     };
+
     PlaylistWidget(QWidget *, PlayerEngine *);
     virtual ~PlaylistWidget();
+
     State state() const
     {
         return _state;
@@ -152,43 +198,62 @@ public:
     {
         return _toggling;
     }
-    void updateSelectItem(const int key);
-    void clear();
     DListWidget *get_playlist()
     {
         return _playlist;
     }
+    void updateSelectItem(const int key);
+    void clear();
     void endAnimation();
+    bool isFocusInPlaylist();
+    /**
+     * @brief resetFocusAttribute
+     * 重置键盘交互属性，确保置首条只有tab键交互生效
+     *
+     * @param atr true为执行，false为跳过
+     */
+    void resetFocusAttribute(bool &atr);
+
 signals:
-    void stateChange();
+    void stateChange(bool isShortcut);
     void sizeChange();
+
 public slots:
-    void togglePopup();
+    /**
+     * @brief togglePopup
+     * 播放列表升起/降下
+     *
+     * @param isShortcut 该函数是否通过快捷键触发
+     */
+    void togglePopup(bool isShortcut);
     void loadPlaylist();
     void openItemInFM();
     void showItemInfo();
     void removeClickedItem(bool isShortcut);
+    void slotCloseTimeTimeOut();
+    void slotCloseItem(QWidget *w);
+    void slotDoubleClickedItem(QWidget *w);
+    void slotRowsMoved();
 
 protected:
     void contextMenuEvent(QContextMenuEvent *cme) override;
-    void dragEnterEvent(QDragEnterEvent *event) override;
-    void dragMoveEvent(QDragMoveEvent *event) override;
-    void dropEvent(QDropEvent *event) override;
+//    void dragEnterEvent(QDragEnterEvent *event) override;
+//    void dragMoveEvent(QDragMoveEvent *event) override;
+//    void dropEvent(QDropEvent *event) override;
     void showEvent(QShowEvent *se) override;
     void paintEvent(QPaintEvent *pe) override;
     void resizeEvent(QResizeEvent *ev) override;
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
 protected slots:
     void updateItemStates();
     void updateItemInfo(int);
     void appendItems();
     void removeItem(int);
-
     void slotShowSelectItem(QListWidgetItem *);
     void OnItemChanged(QListWidgetItem *current, QListWidgetItem *previous);
 
 private:
-
     PlayerEngine *_engine {nullptr};
     MainWindow *_mw {nullptr};
     QWidget *_mouseItem {nullptr};
@@ -199,15 +264,18 @@ private:
     State _state {Closed};
     DLabel *_num {nullptr};
     DLabel *_title {nullptr};
-    bool _toggling {false};
     /// < original row, data>
     QPair<int, PlayItemWidget *> _lastDragged {-1, nullptr};
     int _index {0};
-    PlayItemWidget *_selectItemWgt;
+    PlayItemWidget *pSelectItemWgt;
     void batchUpdateSizeHints();
 
     QPropertyAnimation *paOpen ;
     QPropertyAnimation *paClose ;
+    DPushButton *m_pClearButton;
+
+    bool _toggling {false};
+    bool m_bButtonFocusOut {false};       ///键盘交互标志位
 };
 }
 
