@@ -1,5 +1,9 @@
-/* 
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+/*
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     mouyuankai <mouyuankai@uniontech.com>
+ *
+ * Maintainer: xiepengfei <xiepengfei@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,6 +37,7 @@
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QPainter>
+#include <QPainterPath>
 #include <QGraphicsDropShadowEffect>
 #include <QPropertyAnimation>
 #include <QGraphicsOpacityEffect>
@@ -42,12 +47,11 @@
 #include <DLabel>
 
 DWIDGET_USE_NAMESPACE
-namespace dmr
-{
+namespace dmr {
 class TipPrivate
 {
 public:
-    TipPrivate(Tip *parent) : q_ptr(parent) {}
+    explicit TipPrivate(Tip *parent) : q_ptr(parent) {}
 
     void setBackgroundImage(const QPixmap &srcPixmap);
 
@@ -55,7 +59,7 @@ public:
     int             radius              = 8;
     int             shadowWidth         = 20;
     QMargins        shadowMargins       = QMargins(20, 20, 20, 20);
-    QColor          borderColor         = QColor(0, 0, 0, 0.2 * 255);
+    QColor          borderColor         = QColor(0, 0, 0, static_cast<int>(0.2 * 255));
 
     DLabel          *textLable          = nullptr;
     QFrame          *m_interFrame       = nullptr;
@@ -75,7 +79,6 @@ Tip::Tip(const QPixmap &icon, const QString &text, QWidget *parent)
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowFlags(Qt::ToolTip | Qt::CustomizeWindowHint);
     setAttribute(Qt::WA_TranslucentBackground);
-//    setMaximumWidth(_fontMinWidth);
     setObjectName("Tip");
     setContentsMargins(0, 0, 0, 0);
 
@@ -100,16 +103,9 @@ Tip::Tip(const QPixmap &icon, const QString &text, QWidget *parent)
     d->textLable = new DLabel(text);
     d->textLable->setObjectName("TipText");
     d->textLable->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
-//    d->textLable->setMaximumWidth(this->width());
     d->textLable->setWordWrap(false);
     DFontSizeManager::instance()->bind(d->textLable, DFontSizeManager::T8);
     d->textLable->setForegroundRole(DPalette::ToolTipText);
-//    DPalette pa_name = DApplicationHelper::instance()->palette(d->textLable);
-//    pa_name.setBrush(DPalette::Text, pa_name.color(DPalette::ToolTipText));
-//    pa_name.setBrush(DPalette::ToolTipText, pa_name.color(DPalette::ToolTipText));
-//    d->textLable->setForegroundRole(DPalette::Text);
-//    d->textLable->setForegroundRole(DPalette::ToolTipText);
-//    d->textLable->setPalette(pa_name);
 
     interlayout->addWidget(iconLabel, 0, Qt::AlignVCenter);
     interlayout->addWidget(d->textLable, 0, Qt::AlignVCenter);
@@ -117,15 +113,11 @@ Tip::Tip(const QPixmap &icon, const QString &text, QWidget *parent)
 
     adjustSize();
 
-    auto *bodyShadow = new QGraphicsDropShadowEffect;
+    auto *bodyShadow = new QGraphicsDropShadowEffect(this);
     bodyShadow->setBlurRadius(10.0);
-    bodyShadow->setColor(QColor(0, 0, 0, 0.1 * 255));
+    bodyShadow->setColor(QColor(0, 0, 0, static_cast<int>(0.1 * 255)));
     bodyShadow->setOffset(0, 2.0);
-//    this->setGraphicsEffect(bodyShadow);
     hide();
-//    d->textLable->hide();
-
-    //setFixedHeight(32);
 }
 
 Tip::~Tip()
@@ -133,9 +125,11 @@ Tip::~Tip()
 
 }
 
-void Tip::enterEvent(QEvent* e)
+void Tip::enterEvent(QEvent *e)
 {
     hide();
+
+    QFrame::enterEvent(e);
 }
 
 QBrush Tip::background() const
@@ -188,42 +182,17 @@ void Tip::pop(QPoint center)
     this->show();
     center = center - QPoint(width() / 2, height() / 2);
     this->move(center);
-
-//    auto topOpacity = new QGraphicsOpacityEffect(d->m_interFrame);
-//    topOpacity->setOpacity(1);
-//    d->m_interFrame->setGraphicsEffect(topOpacity);
-
-//    QPropertyAnimation *animation4 = new QPropertyAnimation(topOpacity, "opacity");
-////    animation4->setEasingCurve(QEasingCurve::InCubic);
-//    animation4->setDuration(2000);
-//    animation4->setStartValue(0);
-//    animation4->setKeyValueAt(0.25, 1);
-//    animation4->setKeyValueAt(0.5, 1);
-//    animation4->setKeyValueAt(0.75, 1);
-//    animation4->setEndValue(0);
-//    animation4->start();
-//    animation4->connect(animation4, &QPropertyAnimation::finished,
-//                        animation4, &QPropertyAnimation::deleteLater);
-//    animation4->connect(animation4, &QPropertyAnimation::finished,
-//    this, [ = ]() {
-//        d->m_interFrame->setGraphicsEffect(nullptr);
-//        this->hide();
-//    });
 }
 
 #ifdef _OLD
 void Tip::paintEvent(QPaintEvent *)
 {
     Q_D(Tip);
-//    QFrame::paintEvent(e);
-//    return;
-    bool outer = true;
 
     QPainter painter(this);
     painter.setRenderHints(QPainter::Antialiasing | QPainter::HighQualityAntialiasing);
     auto radius = d->radius;
     auto penWidthf = 1.0;
-//    auto background =  d->background;
     const QPalette pal = QGuiApplication::palette();//this->palette();
     QColor background = pal.color(QPalette::ToolTipBase);
     DPalette pa_name = DApplicationHelper::instance()->palette(d->textLable);
@@ -236,35 +205,23 @@ void Tip::paintEvent(QPaintEvent *)
     auto margin = 2.0;
     auto shadowMargins = QMarginsF(margin, margin, margin, margin);
 
-//    QPainterPath frame;
-//    frame.addRect(rect().marginsRemoved(QMargins(1, 1, 1, 1)));
-//    painter.strokePath(frame, QPen(Qt::red));
-
-    // draw background
     auto backgroundRect = QRectF(rect()).marginsRemoved(shadowMargins);
     QPainterPath backgroundPath;
     backgroundPath.addRoundedRect(backgroundRect, radius, radius);
     painter.fillPath(backgroundPath, background);
 
-    // draw border
     QPainterPath borderPath;
     QRectF borderRect = QRectF(rect());
     auto borderRadius = radius;
     QMarginsF borderMargin(penWidthf / 2, penWidthf / 2, penWidthf / 2, penWidthf / 2);
-    if (outer) {
-        borderRadius += penWidthf / 2;
-        borderRect = borderRect.marginsAdded(borderMargin).marginsRemoved(shadowMargins);
-    } else {
-        borderRadius -= penWidthf / 2;
-        borderRect = borderRect.marginsRemoved(borderMargin).marginsRemoved(shadowMargins);
-    }
+
+    borderRadius += penWidthf / 2;
+    borderRect = borderRect.marginsAdded(borderMargin).marginsRemoved(shadowMargins);
     borderPath.addRoundedRect(borderRect, borderRadius, borderRadius);
     QPen borderPen(borderColor);
     borderPen.setWidthF(penWidthf);
     painter.strokePath(borderPath, borderPen);
 }
-
-}
 #else
 void Tip::paintEvent(QPaintEvent *)
 {
@@ -272,27 +229,16 @@ void Tip::paintEvent(QPaintEvent *)
     QPainter pt(this);
     pt.setRenderHint(QPainter::Antialiasing);
 
-//    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, [=]{
-//        DPalette pa_name = DApplicationHelper::instance()->palette(d->textLable);
-//        pa_name.setBrush(DPalette::Text, pa_name.color(DPalette::ToolTipText));
-//        pa_name.setBrush(DPalette::ToolTipText, pa_name.color(DPalette::ToolTipText));
-//        d->textLable->setForegroundRole(DPalette::Text);
-//        d->textLable->setForegroundRole(DPalette::ToolTipText);
-//        d->textLable->setPalette(pa_name);
-//    });
-
-    if(DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+    if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
         pt.setPen(QColor(0, 0, 0, 10));
         pt.setBrush(QBrush(QColor(247, 247, 247, 220)));
-    }
-    else if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+    } else if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
         pt.setPen(QColor(255, 255, 255, 10));
         pt.setBrush(QBrush(QColor(42, 42, 42, 220)));
-    }
-    else {
+    } else {
         pt.setPen(QColor(0, 0, 0, 10));
         pt.setBrush(QBrush(QColor(247, 247, 247, 220)));
-    }  
+    }
 
     QRect rect = this->rect();
     rect.setWidth(rect.width() - 1);
@@ -306,8 +252,6 @@ void Tip::paintEvent(QPaintEvent *)
 
 void Tip::resizeEvent(QResizeEvent *ev)
 {
-//    resetSize();
-//    update();
     return QWidget::resizeEvent(ev);
 }
 
@@ -325,8 +269,4 @@ void Tip::resetSize(const int maxWidth)
     }
 }
 
-
 }
-
-
-
