@@ -1,5 +1,9 @@
-/* 
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+/*
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     mouyuankai <mouyuankai@uniontech.com>
+ *
+ * Maintainer: xiepengfei <xiepengfei@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,46 +36,57 @@
 #include <DApplication>
 
 namespace dmr {
-VolumeButton::VolumeButton(QWidget* parent)
-    : DIconButton(parent)
+VolumeButton::VolumeButton(QWidget *parent)
+    : DIconButton(parent), m_nVolume(100), m_bMute(false)
 {
-    changeLevel(Level::High);
     setIcon(QIcon::fromTheme("dcc_volume"));
-    setIconSize(QSize(36,36));
+    setIconSize(QSize(36, 36));
 }
 
-void VolumeButton::changeLevel(Level lv)
+void VolumeButton::setVolume(int nVolume)
 {
-    if (_lv != lv) {
-        switch (lv) {
-        case Level::Mute:
-            setIcon(QIcon::fromTheme("dcc_mute")); break;
-        case Level::Off:
-        case Level::Low:
-            setIcon(QIcon::fromTheme("dcc_volumelow")); break;
-        case Level::Mid:
-            setIcon(QIcon::fromTheme("dcc_volumemid")); break;
-        case Level::High:
-            setIcon(QIcon::fromTheme("dcc_volume")); break;
-        }
-        //        setStyleSheet(styleSheet());
-        _lv = lv;
-    }
+    m_nVolume = nVolume;
+
+    changeStyle();
+}
+
+void VolumeButton::setMute(bool bMute)
+{
+    m_bMute = bMute;
+
+    changeStyle();
+}
+
+void VolumeButton::changeStyle()
+{
+    if (m_nVolume >= 66)      //根据音量大小改变图标，更直观的表现
+        setIcon(QIcon::fromTheme("dcc_volume"));
+    else if (m_nVolume >= 33)
+        setIcon(QIcon::fromTheme("dcc_volumemid"));
+    else
+        setIcon(QIcon::fromTheme("dcc_volumelow"));
+
+    if (m_bMute || m_nVolume == 0)
+        setIcon(QIcon::fromTheme("dcc_mute"));
 }
 
 void VolumeButton::enterEvent(QEvent *ev)
 {
     emit entered();
+
+    DIconButton::enterEvent(ev);
 }
 
 void VolumeButton::leaveEvent(QEvent *ev)
 {
     emit leaved();
+
+    DIconButton::leaveEvent(ev);
 }
 
-void VolumeButton::wheelEvent(QWheelEvent* we)
+void VolumeButton::wheelEvent(QWheelEvent *we)
 {
-    //qDebug() << we->angleDelta() << we->modifiers() << we->buttons();
+    //qInfo() << we->angleDelta() << we->modifiers() << we->buttons();
     if (we->buttons() == Qt::NoButton && we->modifiers() == Qt::NoModifier) {
         if (we->angleDelta().y() > 0) {
             emit requestVolumeUp();
@@ -81,5 +96,15 @@ void VolumeButton::wheelEvent(QWheelEvent* we)
     }
 }
 
+//tab键焦点移出时同鼠标移出，响应自动隐藏
+void VolumeButton::focusOutEvent(QFocusEvent *ev)
+{
+    // mips和arm音量条属性为QTool,升起时焦点会在音量条上
+    // 所以不能使用焦点是否变化来让音量调消失
+#if !defined (__mips__) && !defined (__aarch64__)
+    emit leaved();
+#endif
+    DIconButton::focusOutEvent(ev);
 }
 
+}
